* this do-file combines monthly price data, quarterly production data, and annual trade data into a single dataset
* written by Treb on Aug 13, 2013

global date = "081313"
global user = c(username)
global dropbox = "C:\Users\\$user\Dropbox"
global dir = "$dropbox\Research\Data\Philippines\Agricultural Trade"
cd "$dir"

global dir_prices = "$dropbox\Research\Data\Philippines\Production and Price Data\Monthly Prices"
global dir_prodrice = "$dropbox\Research\Data\Philippines\Production and Price Data\Rice and Corn\Quantity"
global dir_id = "$dropbox\Research\Data\Philippines"

cap log close
log using agtrade_monthly_$date.log, replace
clear

* Using the prices to make the dataset

	use "$dir_prices/monthly_wholesale_prices_cleaned.dta"
		gen year = real(substr(date,1,4))
		gen month = month(date(date,"YM"))
		drop if month==.
		
		* averaging prices within agprod_name
			bysort province_id year month agprod_name: egen price_mean = mean(price)
			
		* one observation
			bysort province_id year month agprod_name: keep if _n==1
			keep province_id province_name year month agprod_name price_mean
			ren price_mean price
			
		* only keeping observations with prices
			keep if price<.
			
	* making the bilateral data set

		* destination
			ren province_name province_dest_name
			ren province_id province_dest_id
			ren price price_dest
			tempfile temp_dest
			save `temp_dest', replace
			
		* origin 
			ren province_dest_name province_orig_name
			ren province_dest_id province_orig_id
			ren price_dest price_orig
			
		* joining
			joinby agprod_name year month using `temp_dest'
			order province_orig_name province_orig_id province_dest_name province_dest_id agprod_name year month price_orig price_dest
			sort province_orig_id province_dest_id agprod_name year month
			by province_orig_id province_dest_id agprod_name year month: assert _n==1
			
		* getting rid of origin = destination observations
			drop if province_orig_id == province_dest_id
			
* loading on the trade flows
	preserve
	clear
	
	use "$dir\agtrade_zeros.dta"
	keep year province_orig_id province_orig_name province_dest_id province_dest_name agprod_name quantity value tao theta* fsub* imports* exports* fsub* distance production*
		order province_orig_name province_orig_id province_dest_name province_dest_id agprod_name year
		sort province_orig_id province_dest_id agprod_name year
		
	tempfile temp_trade
	save `temp_trade', replace
	
	restore
	merge province_orig_id province_dest_id agprod_name year using `temp_trade'
	tab _merge
	keep if _merge==1 | _merge==3 /* otherwise, we do not have price data */
	keep if production_orig<. /* only looking at places that are producing */
	
* loading on quarterly production data for rice and corn
	preserve
	clear

	* getting province_id's 
		use "$dir_id\province_id_MASTER.dta"
		keep province_id province_name
		sort province_name
		tempfile temp_prov
		save `temp_prov', replace
		clear
	
	use "$dir_prodrice\1994 - 2009 rice and corn (cleaned).dta"
	
	* getting agprod_name
		gen agprod_name = "Corn" if crop == "Corn"
		replace agprod_name = "Rice" if crop =="Palay"
		keep if agprod_name ~= ""
		bysort province_name year quarter agprod_name: assert _n==1
		drop crop
		
	* getting annual shares
		expand 3
		sort province_name agprod_name year quarter
		by province_name agprod_name year: gen month = _n
		gen q_month = real(quantity) / 3 /* assuming equal production within each month in that quarter */
		
		by province_name agprod_name year: egen q_annual = sum(q_month)
		gen fraction = q_month / q_annual
		lab var fraction "Fraction of annual production occuring in that month"
		
	* getting province id
		replace province_name = upper(trim(province_name))
			replace province_name = "OCCIDENTAL MINDORO" if province_name == "MINDORO OCCIDENTAL"
			replace province_name = "ORIENTAL MINDORO" if province_name == "MINDORO ORIENTAL"
			replace province_name = "WESTERN SAMAR" if province_name == "SAMAR"
			replace province_name = "DAVAO DEL NORTE" if province_name == "DAVAO PROVINCE"
			replace province_name = "COTABATO" if province_name == "NORTH COTABATO"
		keep province_name year month agprod_name fraction
		order province_name agprod_name year month fraction
		sort province_name agprod_name year month
		merge province_name using `temp_prov'
		keep if _merge==3
		drop _merge
		
	* renaming and preparing for merge
		ren province_name province_orig_name
		ren province_id province_orig_id
		sort province_orig_id agprod_name year month
		tempfile temp_frac
		save `temp_frac', replace
		
	restore
	
	* merging 
		drop _merge
		sort province_orig_id agprod_name year month
		merge province_orig_id agprod_name year month using `temp_frac'
		drop if _merge==2 /* places without prices */
		drop _merge
		
* Cleaning up

	* Places without fraction have 1/12 fraction (e.g. for all crops other than rice and corn)
		replace fraction = 1/12 if fraction==. 

	lab dat "Monthly prices, quarterly production, and annual trade flows"
	save agtrade_monthly.dta, replace
	
	log close
	exit
	
		
		
	
		

	

			
	
