* This do-file sees how well different models are able to match observed out-of-sample trade flows given only prices
* written by Treb on 9/3/13

clear
global date = "090313"

if c(username)=="dwi902" {
	global dropbox = "C:\Users\dwi902\Dropbox"
}

global dir = "$dropbox\Research\Trade\Information\Simulation\Out of Sample - Trade Prediction"
global dir_data = "$dropbox\Research\Data\Philippines\Agricultural Trade"
global dir_rain = "$dropbox\Research\Data\Philippines\Rainfall"
global dir_dem = "$dropbox\Research\Data\Philippines\2000 Demographic Census"
global dir_yield = "$dropbox\Research\Data\Philippines\Provincial Data"
cd "$dir"
cap log close
log using outofsample_$date.log, replace


*** Step #1: Estimate the trade frictions
	* I consider 4 models: complete information (transportation costs only), incomplete information (transportation costs & fixed cost of search only), incomplete information (search probabilities & fixed cost of search only), and incomplete information (all search frictions).
	* The "in-sample" is the first half of the dataset (1995-2001) and the "out-of-sample" is the second half of the dataset (2002-2009)
	
		use "$dir_data\agtrade_monthly.dta"
		keep if year<=2001 /* only estimating based on in-sample */

		** First, estimating the taus (and the sigma) using an IV probit (which is easier to do in Stata)
			
			* getting rainfall for IV of price ratio
				* loading rainfall data
					preserve
						clear
						use "$dir_rain\province_rain_030911.dta"
							* Converting into monthly measures
							gen month = month(date)
							gen year = year(date)
							bysort province_id year month: egen rainfall_mean = mean(rainfall_predict)
							bysort province_id year month: egen rainfall_sd = sd(rainfall_predict)
							bysort province_id year month: keep if _n==1
							lab var rainfall_mean "Mean daily rainfall over the month"
							lab var rainfall_sd "Std.dev. of daily rainfall over the month"
							drop rainfall_predict date
							
							sort province_id year month
							tempfile temp_rain
							save `temp_rain', replace			
					restore
					
				* merging
					ren province_orig_id province_id
					sort province_id year month
					merge province_id year month using `temp_rain'
					tab _merge
					ren province_id province_orig_id
					ren rainfall_mean rainfall_mean_orig
					ren rainfall_sd rainfall_sd_orig
					keep if _merge==3
					drop _merge
					
					ren province_dest_id province_id
					sort province_id year month
					merge province_id year month using `temp_rain'
					tab _merge
					ren province_id province_dest_id
					ren rainfall_mean rainfall_mean_dest
					ren rainfall_sd rainfall_sd_dest
					keep if _merge==3
					drop _merge		
					
					gen rainfall_mean_orig2 = rainfall_mean_orig^2
					gen rainfall_mean_dest2 = rainfall_mean_dest^2

			* estimating fixed effects in stata using probit transformation
				
					gen export = quantity>0
					gen ln_priceratio = ln(price_dest / price_orig)
					keep if fraction>0 /* only keeping months where production occurs */

				* identifying switchers
					bysort province_orig_id province_dest_id agprod_name: egen temp_max_export = max(export)
					bysort province_orig_id province_dest_id agprod_name: egen temp_min_export = min(export)
					keep if temp_max_export==1 & temp_min_export==0 /* only ones where we sometimes observe trade and other times do not */
					
				* collapsing down to year observations
					bysort province_orig_id province_dest_id agprod_name year: egen temp_max_priceratio = max(ln_priceratio)
					keep if temp_max_priceratio == ln_priceratio /* keeping the month with the greatest price ratio */
					bysort province_orig_id province_dest_id agprod_name year: keep if _n==1 /* in case of ties, just keep one */
					
					
				* here is the regression
					egen temp_id = group(province_orig_id province_dest_id agprod_name)

					xi: ivprobit export i.temp_id (ln_priceratio = rainfall_*)
					local sigma = 1/_b[ln_priceratio] /* this is the estimated standard deviation */
					disp "Estimated standard deviation: " `sigma'
					* getting the estimated taus
						cap drop tau_est_incomplete
						gen tau_est_incomplete = .
						replace tau_est_incomplete = exp(-(_b[_cons]) / _b[ln_priceratio]) if temp_id==1 /* excluded fixed effect */
						qui sum temp_id
						local id_max = r(max)
						forvalues i=1/`id_max' {
							qui cap replace tau_est_incomplete = exp(-(_b[_cons] + _b[_Itemp_id_`i']) / _b[ln_priceratio]) if temp_id==`i'
						}
					
				* saving
					gen sigma = `sigma'
					lab var sigma "Estimated std.dev. of transportation costs"
					keep province_orig_id province_dest_id agprod_name tau_est_incomplete sigma
					sort province_orig_id province_dest_id agprod_name
					tempfile temp_tau
					save `temp_tau', replace
					
				* merging back on
					clear
					use "$dir_data\agtrade_monthly.dta"
					sort province_orig_id province_dest_id agprod_name
					merge province_orig_id province_dest_id agprod_name using `temp_tau'
					tab _merge
					drop _merge
					cap drop temp*
					gen temp_export = quantity>0
					drop if fraction == 0 /* only export in months where you've produced */
					bysort province_orig_id province_dest_id agprod_name: egen temp_max = max(temp_export)
					bysort province_orig_id province_dest_id agprod_name: egen temp_min = min(temp_export)
					assert tau_est_incomplete==. if temp_min==1 | temp_max==0
					replace tau_est_incomplete = -99 if tau_est_incomplete ==. & temp_min==1 /* always export */
					replace tau_est_incomplete = 99 if tau_est_incomplete ==. & temp_max==0 /* never export */
					cap drop temp*
					bysort province_orig_id province_dest_id agprod_name: assert tau_est_incomplete==tau_est_incomplete[1]
	
	* Trade flows (annual) and prices (monthly)

		* putting prices in 2000 PHP
			foreach var of var price* {
				replace `var' = `var'/(0.768) if year==1995
				replace `var' = `var'/(0.843) if year==1996
				replace `var' = `var'/(0.871) if year==1997
				replace `var' = `var'/(0.943) if year==1998
				replace `var' = `var'/(0.985) if year==1999
				replace `var' = `var'/(1) if year==2000
				replace `var' = `var'/(1.047) if year==2001
				replace `var' = `var'/(1.069) if year==2002
				replace `var' = `var'/(1.093) if year==2003
				replace `var' = `var'/(1.116) if year==2004
				replace `var' = `var'/(1.239) if year==2005
				replace `var' = `var'/(1.307) if year==2006
				replace `var' = `var'/(1.350) if year==2007
				replace `var' = `var'/(1.533) if year==2008
				replace `var' = `var'/(1.6423) if year==2009
			}
			
		preserve
		bysort province_orig_id province_dest_id agprod_name year: assert quantity == quantity[1]
		bysort province_orig_id province_dest_id agprod_name year month: assert price_dest == price_dest[1]
		bysort province_orig_id agprod_name year month: assert price_orig == price_orig[1]
		bysort province_orig_id province_dest_id agprod_name year month: keep if _n==1
		bysort province_orig_id province_dest_id agprod_name: assert tau_est_incomplete==tau_est_incomplete[1]
		keep province_orig_id province_dest_id agprod_name year month quantity price_orig price_dest tau_est_incomplete
		egen temp_id = group(province_orig_id agprod_name year month)
		
		reshape wide price_dest quantity tau_est_incomplete, i(temp_id) j(province_dest_id)
		foreach var of var price_dest* quantity* tau_est_incomplete* {
			qui replace `var' = 999 if `var'==. /* replacing missing variables so that matlab can read them */
		}
		tempfile temp_trade
		save `temp_trade', replace
		restore

	* Production (monthly) 
		preserve
		replace production_orig = production_orig / 1.53 if agprod_name=="Rice" /* this is the BAS estimate of the typical milling recover (65% of dry palay) */
		bysort province_orig_id agprod_name year: assert production_orig==production_orig[1]
		bysort province_orig_id agprod_name: assert fsub_orig==fsub_orig[1]
		bysort province_orig_id agprod_name year month: keep if _n==1
		bysort province_orig_id agprod_name year: egen temp = sum(fraction) /* what fraction of production occurs in months where there exist export markets (i.e. we observe prices elsewhere) */

		gen prod_fortrade = fraction*production_orig/temp /* amount produced in each month, forcing all trade to occur when prices are observed */
		keep province_orig_id agprod_name year month prod_fortrade
		sort province_orig_id agprod_name year month
		tempfile temp_prod
		save `temp_prod', replace
		restore

	* Land distribution (crop-province) specific
		preserve
		bysort province_orig_id agprod_name: assert theta_orig==theta_orig[1]
		bysort province_orig_id agprod_name: keep if _n==1
		keep province_orig_id agprod_name theta_orig
		tempfile temp_theta
		save `temp_theta', replace
		restore
		
	* merging
		clear
		use `temp_trade'
		sort province_orig_id agprod_name year month
		merge province_orig_id agprod_name year month using `temp_prod'
		tab _merge
		drop _merge
		
		sort province_orig_id agprod_name 
		merge province_orig_id agprod_name using `temp_theta'
		tab _merge
		drop _merge
		
	* exporting to matlab
		keep if prod_fortrade<. & theta_orig<.
		egen agprod_id = group(agprod_name)
		gen year_id = year-1994
		egen province_orig_id_matlab = group(province_orig_id)
		sort province_orig_id_matlab agprod_id year_id month
		
		preserve
		keep if year<=2001
		
		outsheet province_orig_id_matlab agprod_id year_id month using "id_$date.dat", non replace
		outsheet price_dest* using "dest_prices_$date.dat", replace non
		outsheet price_orig using "orig_prices_$date.dat", replace non
		outsheet quantity* using "tradeflows_$date.dat", replace non
		outsheet prod_fortrade using "production_$date.dat", replace non
		outsheet theta_orig using "theta_$date.dat", replace non
		outsheet tau_est_incomplete* using "tauest_$date.dat", replace non
		
		restore
		preserve
		keep if year>=2002
		replace year_id = year-2001
		
		outsheet province_orig_id_matlab agprod_id year_id month using "id_out_$date.dat", non replace
		outsheet price_dest* using "dest_prices_out_$date.dat", replace non
		outsheet price_orig using "orig_prices_out_$date.dat", replace non
		outsheet quantity* using "tradeflows_out_$date.dat", replace non
		outsheet prod_fortrade using "production_out_$date.dat", replace non
		outsheet tau_est_incomplete* using "tauest_out_$date.dat", replace non
		
		restore
		
		* for the estimated standard deviation of the taus
		preserve
			clear
			set obs 1
			gen sigma = `sigma'
			outsheet sigma using "sigmaest_$date.dat", replace non
		restore		
		
	* saving
		save outofsample_tomatlab_$date.dta, replace
		
	

***