* This do-file prepares the data for structural estimation in Matlab, then loads the results
* written by Treb on Aug 22, 2013

clear
global date = "090513"

if c(username)=="dwi902" {
	global dropbox = "C:\Users\dwi902\Dropbox"
}

global dir = "$dropbox\Research\Trade\Information\Empirics\Reduced Form - Monthly"
global dir_data = "$dropbox\Research\Data\Philippines\Agricultural Trade"
global dir_rain = "$dropbox\Research\Data\Philippines\Rainfall"
global dir_struct_est = "$dropbox\Research\Trade\Information\Empirics\Structural Estimation - Monthly"
global dir_phone = "$dropbox\Research\Data\Philippines\Cell phones\Towers"
cd "$dir"
cap log close
log using empirical_puzzles_monthly_$date.log, replace

		
*** Empirical Puzzle: Price dispersion much larger than freight costs
	clear
	use "$dir_data\agtrade_monthly.dta"
	gen price_ratio = price_dest / price_orig
	bysort province_orig_id province_dest_id agprod_name year: egen max_price_ratio = max(price_ratio) 
	bysort province_orig_id province_dest_id agprod_name year: keep if _n==1
	lab var max_price_ratio "Maximum price ratio of destination to origin price within year"
	cap drop tau_freight_ratio
	gen tau_freight_ratio = (max_price_ratio -1) / (tao-1) 
	gen ln_ratio = ln(tau_freight_ratio)
	keep if tao>0
	tabstat tau_freight_ratio, by(agprod_name) stat(N mean sd median)
	sum ln_ratio
	local gmean = exp(r(mean))
	disp "Total geometric mean is: `gmean'"
	keep ln_ratio agprod_name
	collapse (mean) ln_ratio, by(agprod_name)
	gen g_mean = exp(ln_ratio)
	drop ln_ratio
	lab var g_mean "Geometric mean"
	count
	local N = r(N)+1
	set obs `N'
	replace agprod_name = "Total" if _n==_N
	replace g_mean = `gmean' if _n==_N
	list	

*** Empirical Puzzle: Trade flows decline much more quickly with distance than freight costs
	clear
	estimates clear
	use "$dir_data\agtrade_monthly.dta"
			
		bysort province_orig_id province_dest_id agprod_name year: keep if _n==1

		* Generating logs
			cap drop ln*
			gen ln_distance = log(distance)
			
			/* converting back to PHP instead of ad valorem costs */
			gen freight = (tao-1)*value
			replace freight = . if tao==0 /* 0 indicates missing */
			gen ln_freight = ln(freight)
			gen frac_freight = 100*freight / value
			gen ln_frac_freight = ln(frac_freight)

			gen ln_quantity = log(quantity)
			gen ln_value = log(value)
			keep if ln_freight<. & ln_distance<. & ln_quantity<.
			
		* Fixed effects
			cap drop FE*
			egen FE_origprodyr = group(province_orig_id agprod_name year)
			egen FE_destprodyr = group(province_dest_id agprod_name year)
			
		* doing the regressions
			
			xi: areg ln_quantity ln_distance i.FE_origprodyr, a(FE_destprodyr)
				estimates store a1
				estadd local FE_destprodyr "Yes"
				estadd local FE_origprodyr "Yes"
				
			xi: areg ln_quantity ln_distance ln_frac_freight i.FE_origprodyr, a(FE_destprodyr)
				estimates store a2
				estadd local FE_destprodyr "Yes"
				estadd local FE_origprodyr "Yes"
				
			xi: areg ln_value ln_distance i.FE_origprodyr, a(FE_destprodyr)
				estimates store a3
				estadd local FE_destprodyr "Yes"
				estadd local FE_origprodyr "Yes"
				
			xi: areg ln_value ln_distance ln_frac_freight i.FE_origprodyr, a(FE_destprodyr)
				estimates store a4
				estadd local FE_destprodyr "Yes"
				estadd local FE_origprodyr "Yes"
								
			xi: areg ln_frac_freight ln_distance i.FE_origprodyr, a(FE_destprodyr)
				estimates store a5
				estadd local FE_destprodyr "Yes"
				estadd local FE_origprodyr "Yes"
				
		
		* Making the table
				lab var ln_distance "Log shipping distance"
				lab var ln_frac_freight "Log freight costs (% of value)"

				estout a* using empiciralpuzzles1_$date.tex, ///
					type style(tex) replace title("Trade flows, freight costs, and shipping distance") ///
					prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:puzzle1} ///
					\begin{tabular}{llllll}) ///
					posthead("\hline") prefoot("\hline") ///
					varlabels(_cons "Constant")  ///
					cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
					stats(FE_origprodyr FE_destprodyr r2 N, fmt(%6.3f %6.3f %6.3f %6.0f) ///
					labels("Origin-Commodity-Year FE" "Destination-Commodity-Year FE"  "R-squared" "Observations")) ///
					mgroups("Log quantity shipped (kg.)" "Log value shipped (PHP)" "Log freight costs (% of value)", lhs("Dependent variable:") pattern(1 0 1 0 1) span prefix(\multicolumn{@span}{c}{) suffix(})) ///
					mlabels(none) starlevels(* .1 ** .05 *** .01) collabels(none) ///
					drop(temp* _cons _I* o.*, relax) ///
					label numbers ///
					postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} Ordinary least squares.  Each observation is an origin-destination-commodity-year quadruplet in which trade occurred and freight costs were recorded. ///
						Standard errors are reported in parentheses. Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. The p-values reported for the  test for equality of coefficients across regressions come from a seeminly unrelated estimation procedure robust to heteroskedasticity. ///
					\end{minipage} \end{table} ) substitute($ \$ !$ $ ~ .\ % \%)	
	

*** Empirical puzzle: pass-through is far from complete
	clear
	use "$dir_data\agtrade_monthly.dta"
	
	* loading rainfall data
		preserve
			clear
			use "$dir_rain\province_rain_030911.dta"
				* Converting into monthly measures
				gen month = month(date)
				gen year = year(date)
				bysort province_id year month: egen rainfall_mean = mean(rainfall_predict)
				bysort province_id year month: egen rainfall_sd = sd(rainfall_predict)
				bysort province_id year month: keep if _n==1
				keep province_id year month rainfall_mean rainfall_sd
				egen temp = group(province_id year)
				reshape wide rainfall_mean rainfall_sd, i(temp) j(month)
				drop temp
				sort province_id year
				tempfile temp_rain
				save `temp_rain', replace			
		restore
			
		* merging
			ren province_orig_id province_id
			sort province_id year
			merge province_id year using `temp_rain'
			tab _merge
			keep if _merge==3
			drop _merge
			ren province_id province_orig_id
	
	* loading cellphone data
		preserve
			clear
			use "$dir_phone\cell_access_060311.dta"
			keep province_id year month towers 
			sort province_id year month
			tempfile temp_phone
			save `temp_phone', replace
		restore
		
		* merging
			ren province_orig_id province_id
			sort province_id year month
			merge province_id year month using `temp_phone'
			tab _merge
			drop if _merge==2
			drop _merge
			ren province_id province_orig_id
			ren towers towers_orig
			
			ren province_dest_id province_id
			sort province_id year month
			merge province_id year month using `temp_phone'
			tab _merge
			drop if _merge==2
			drop _merge
			ren province_id province_dest_id
			ren towers towers_dest
		
	* Constructing the maximum price ratio within year across months
		cap drop temp*
		gen temp_pr = price_dest / price_orig
		bysort province_orig_id province_dest_id agprod_name year: egen temp_pr_max = max(temp_pr)
		keep if temp_pr_max==temp_pr /* only keeping the maximum price ratio */
		bysort province_orig_id province_dest_id agprod_name year: keep if _n==1 /* one observation per province pair per year */
		cap drop temp
		
	* Only keeping observations where trade occurs (so arbitrage is supposed to bind)
		keep if quantity>0
		
	* Only looking at origin-destination pairs where corn and rice are exported in subsequent years
		egen agprod_id = group(agprod_name)
		
	* Only keeping necessary variables
		keep province_orig_id province_dest_id year agprod_* price_orig price_dest rainfall* towers*
		
	* Getting the price ratio of corn to price & down to one variable per origin-destination-year
		cap drop temp*
		egen temp = group(province_orig_id province_dest_id year)
		tabstat agprod_id, by(agprod_name)
		drop agprod_name
		reshape wide price_orig price_dest towers*, i(temp) j(agprod_id)
		drop temp
		cap drop ln_pr_*
		gen ln_pr_dest = log(price_dest5 / price_dest11) /* ratio of price of corn to rice */
		gen ln_pr_orig = log(price_orig5 / price_orig11)
		
	* cell phone
		cap drop phone
		gen phone_o = max(towers_orig5,towers_orig11)>0
		gen phone_d = max(towers_dest5,towers_dest11)>0
		gen phone_b = phone_o*phone_d
		
	* Generating the fixed effects 
		cap drop FE*
		egen FEorigdest = group(province_orig_id province_dest_id)
		tsset FEorigdest year, yearly
		
	* generating the interactions
		cap drop Dln_pr_origX*
		cap drop X*
		
		foreach var of var phone_* {
			gen Dln_pr_origX`var' = `var'*D.ln_pr_orig
			foreach var2 of var rainfall* {
				gen X`var'D`var2' = `var'*D.`var2'
			}
		}
		
	* Here are the regressions
	
		* non interactions: OLS
			xi: reg D.ln_pr_dest D.ln_pr_orig i.year
				estimates store b1
				
				test _b[D.ln_pr_orig]==1
				local p1 = r(p)
				
				estimates restore b1
					estadd scalar p1 `p1'
					estadd local FEyear "Yes"
			
		* non interactions: IV
			xi: ivregress 2sls D.ln_pr_dest (D.ln_pr_orig = D.rainfall*) i.year
				estimates store b2
				
				test _b[D.ln_pr_orig]==1
				local p1 = r(p)
				
				estimates restore b2
					estadd scalar p1 `p1'
					estadd local FEyear "Yes"				
			
		* interaction for phone both: OLS
			xi: reg D.ln_pr_dest D.ln_pr_orig Dln_pr_origXphone_b i.year
				estimates store b3
				
				test _b[D.ln_pr_orig]==1
				local p1 = r(p)
				
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_b]==1
				local p2 = r(p)
				
				estimates restore b3
					estadd scalar p2 `p1'
					estadd scalar p3 `p2'
					estadd local FEyear "Yes"
			
		* interaction for phone both: IV
			xi: ivregress 2sls D.ln_pr_dest (D.ln_pr_orig Dln_pr_origXphone_b = D.rainfall* Xphone_b* phone_b) i.year
				estimates store b4
				
				test _b[D.ln_pr_orig]==1
				local p1 = r(p)
				
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_b]==1
				local p2 = r(p)
				
				estimates restore b4
					estadd scalar p2 `p1'
					estadd scalar p3 `p2'
					estadd local FEyear "Yes"
			
	* Other regressions
	
		* include all types of cell phones (origin only, destination only, & both)
			reg D.ln_pr_dest D.ln_pr_orig Dln_pr_origXphone_* i.year
				test _b[D.ln_pr_orig]==1
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_o] == 1
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_d] ==1
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_o] + _b[Dln_pr_origXphone_d] + _b[Dln_pr_origXphone_b]==1			
			
			ivregress 2sls D.ln_pr_dest (D.ln_pr_orig Dln_pr_origXphone_* = D.rainfall* Xphone_* phone_*) i.year
				test _b[D.ln_pr_orig]==1
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_o] == 1
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_d] ==1
				test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_o] + _b[Dln_pr_origXphone_d] + _b[Dln_pr_origXphone_b]==1
			
		* including all crops
			preserve
		
			* back to long form
				drop phone_*
				cap drop temp*
				egen temp = group(province_orig_id province_dest_id year)
				reshape long price_orig price_dest towers_orig towers_dest, i(temp) j(agprod_id) 
				
			* generating price ratios across all crops
				cap drop temp*
				egen temp = group(province_orig_id province_dest_id year)
				gen temp2 = price_orig<. & price_dest<.
				bysort agprod_id: egen temp3 = sum(temp2)
				egen temp4 = group(temp3)
				tabstat temp4, by(agprod_id)
				tset temp temp4 /* this orders the commodities by the number of observations */
				cap drop ln_pr*
				gen ln_price_orig = log(price_orig)
				gen ln_price_dest = log(price_dest)
				gen ln_pr_orig = D.ln_price_orig /* taking differences across crops in order of agprod_id */
				gen ln_pr_dest = D.ln_price_dest /* taking differences across crops in order of agprod_id */
				
			* cell phone
				cap drop phone
				gen phone_o = max(towers_orig,L.towers_orig)>0
				gen phone_d = max(towers_dest,L.towers_dest)>0
				gen phone_b = phone_o*phone_d
				
			* now back to across years
				cap drop temp*
				egen temp = group(province_orig_id province_dest_id agprod_id)
				tset temp year, yearly /* now will take differences across years in the across crop price ratios */
			
			* generating the interactions
				cap drop Dln_pr_origX*
				cap drop X*
				
				foreach var of var phone_* {
					gen Dln_pr_origX`var' = `var'*D.ln_pr_orig
					foreach var2 of var rainfall* {
						gen X`var'D`var2' = `var'*D.`var2'
					}
				}	
				
			* fixed effect
				egen FEyearprod = group(year agprod_id) /* need this because we have different types of crop ratios */
				
			* regressions
	
				* non interactions: OLS
					reg D.ln_pr_dest D.ln_pr_orig i.FEyearprod
					test _b[D.ln_pr_orig]==1
					
				* non interactions: IV
					ivregress 2sls D.ln_pr_dest (D.ln_pr_orig = D.rainfall*) i.FEyearprod
					test _b[D.ln_pr_orig]==1
					
				* interaction for phone both: OLS
					reg D.ln_pr_dest D.ln_pr_orig Dln_pr_origXphone_b i.FEyearprod
					test _b[D.ln_pr_orig]==1
					test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_b]==1
					
				* interaction for phone both: IV
					ivregress 2sls D.ln_pr_dest (D.ln_pr_orig Dln_pr_origXphone_b = D.rainfall* Xphone_b* phone_b) i.FEyearprod
					test _b[D.ln_pr_orig]==1
					test _b[D.ln_pr_orig] + _b[Dln_pr_origXphone_b]==1			
					
			restore
			
		* Making the table				
			estout b* using puzzle_passthrough_$date.tex, ///
				type style(tex) replace title("Price pass-through and mobile phone access") ///
				prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:pricearbitrage} ///
				\begin{tabular}{lllll}) ///
				posthead("\hline") prefoot("\hline") ///
				varlabels(D.ln_pr_orig "Change in log origin price ratio" Dln_pr_origXphone_b "Change in log origin price ratio * Mobile phone access" _cons "Constant") wrap ///
				cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
				stats(FEyear r2 N p1 p2 p3, fmt(%6.3f %6.3f %6.0f %6.3f %6.3f %6.3f) labels("Year Fixed Effects" "R-squared" "Observations" "Test for complete pass-through (p-value)" "Test for complete pass-through without mobile phones (p-value)"  "Test for complete pass-through with mobile phones (p-value)" )) ///
				starlevels(* .1 ** .05 *** .01) collabels(none) mlabels("OLS" "2SLS" "OLS" "2SLS", lhs("Dep. var.: change in log destination price ratio")) ///
				drop(temp* _cons _I* o.*, relax) ///
				label numbers ///
				postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} First differences.  The dependent variable is the change in the log wholesale price ratio of corn to rice in the destination province.  ///
					Each observation is an exporter-importer-year triplet.  The prices used in price ratio are the monthly prices in which the ratio of importer to exporter price is largest. ///
					The change in the origin price ratio of corn to rice is instrumented with the change in the mean and standard deviation of monthly rainfall.  ///
					The p-value of the test whether the estimated coefficient is one (as is implied by price arbitrage) is reported for all columns. Mobile phone access is an indicator variable equal to one if a civilian cell phone tower exists in both the exporting and importing province.  ///  
					Standard errors are reported in parentheses.  Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. ///
				\end{minipage} \end{table} ) substitute($ \$)	


*** Empirical puzzle: responsiveness to destination prices are increasing in producer heterogeneity
	clear
	use "$dir_data\agtrade_monthly.dta"
	
	* loading rainfall data
		preserve
			clear
			use "$dir_rain\province_rain_030911.dta"
				* Converting into monthly measures
				gen month = month(date)
				gen year = year(date)
				bysort province_id year month: egen rainfall_mean = mean(rainfall_predict)
				bysort province_id year month: egen rainfall_sd = sd(rainfall_predict)
				bysort province_id year month: keep if _n==1
				lab var rainfall_mean "Mean daily rainfall over the month"
				lab var rainfall_sd "Std.dev. of daily rainfall over the month"
				drop rainfall_predict date
				
				sort province_id year month
				tempfile temp_rain
				save `temp_rain', replace			
		restore
			
		* merging
			ren province_orig_id province_id
			sort province_id year month
			merge province_id year month using `temp_rain'
			tab _merge
			ren province_id province_orig_id
			ren rainfall_mean rainfall_mean_orig
			ren rainfall_sd rainfall_sd_orig
			keep if _merge==3
			drop _merge
			
			ren province_dest_id province_id
			sort province_id year month
			merge province_id year month using `temp_rain'
			tab _merge
			ren province_id province_dest_id
			ren rainfall_mean rainfall_mean_dest
			ren rainfall_sd rainfall_sd_dest
			keep if _merge==3
			drop _merge		
			
	* converting to 2000 PHP
		foreach var of var price* {
			replace `var' = `var'/(0.768) if year==1995
			replace `var' = `var'/(0.843) if year==1996
			replace `var' = `var'/(0.871) if year==1997
			replace `var' = `var'/(0.943) if year==1998
			replace `var' = `var'/(0.985) if year==1999
			replace `var' = `var'/(1) if year==2000
			replace `var' = `var'/(1.047) if year==2001
			replace `var' = `var'/(1.069) if year==2002
			replace `var' = `var'/(1.093) if year==2003
			replace `var' = `var'/(1.116) if year==2004
			replace `var' = `var'/(1.239) if year==2005
			replace `var' = `var'/(1.307) if year==2006
			replace `var' = `var'/(1.350) if year==2007
			replace `var' = `var'/(1.533) if year==2008
			replace `var' = `var'/(1.6423) if year==2009
		}
	
	* generating logs
		cap drop ln_*
		gen ln_quantity = log(quantity)
		gen ln_price_dest = log(price_dest)
		gen ln_price_orig = log(price_orig)
		
	* generating interactions
		cap drop ln_price_destX*
		gen ln_price_destXtheta_orig = ln_price_dest*theta_orig
		cap drop thetaX*
		foreach var of var rainfall_* {
			gen thetaX`var' = `var'*theta_orig
		}
		
	* generating Fixed effects
		cap drop FE*
		egen FE_origdestprod = group(province_orig_id province_dest_id agprod_name)
		egen FE_origdestprodyr = group(province_orig_id province_dest_id agprod_name year)
		egen FE_prodmon = group(agprod_name month)
		egen FE_origyrmon = group(province_orig_id year month)
		
	* regressions for heterogeneity
	
		* keeping the sample constant
			xtset FE_origdestprod
			qui xi: xtivreg2 ln_quantity i.FE_prodmon (ln_price_dest ln_price_orig ln_price_destXtheta_orig = rainfall_* thetaX*) , fe cluster(FE_origdestprod)
			keep if e(sample)
			bysort FE_origdestprod: drop if _N==1
			
		* for the summary stat table: how many observations are there for each crop?
			cap drop temp*
			bysort province_orig_id province_dest_id agprod_name year: assert quantity==quantity[1]
			bysort province_orig_id province_dest_id agprod_name year: gen temp = _n==1
			tab agprod_name /* total number of bilateral price observations */
			tab agprod_name if temp==1
	
		* OLS
			xi: areg ln_quantity ln_price_dest ln_price_orig , a(FE_origdestprod) cluster(FE_origdestprod)
				estimates store c1
				estadd local FE_origdestprod "Yes"
				
			xi: areg ln_quantity ln_price_dest ln_price_orig ln_price_destXtheta_orig, a(FE_origdestprod) cluster(FE_origdestprod)
				estimates store c3
				estadd local FE_origdestprod "Yes"
			
			
			* with product-month FE
				xi: xtreg ln_quantity ln_price_dest ln_price_orig i.FE_prodmon, fe cluster(FE_origdestprod)
					estimates store c5
					estadd local FE_origdestprod "Yes"
					estadd local FE_prodmon "Yes"
					estadd scalar r2_treb e(r2_w)
					
				xi: xtreg ln_quantity ln_price_dest ln_price_orig ln_price_destXtheta_orig i.FE_prodmon, fe cluster(FE_origdestprod)
					estimates store c7
					estadd local FE_origdestprod "Yes"
					estadd local FE_prodmon "Yes"
					estadd scalar r2_treb e(r2_w)
				
		* 2SLS
			xi: xtivreg2 ln_quantity (ln_price_dest ln_price_orig = rainfall_*) , fe cluster(FE_origdestprod)
				estimates store c2
				estadd local FE_origdestprod "Yes"
				
			xi: xtivreg2 ln_quantity (ln_price_dest ln_price_orig ln_price_destXtheta_orig = rainfall_* thetaX*) , fe cluster(FE_origdestprod)
				estimates store c4
				estadd local FE_origdestprod "Yes"
	
			* with product-month FE
				xi: xtivreg2 ln_quantity i.FE_prodmon (ln_price_dest ln_price_orig = rainfall_mean_orig rainfall_sd_orig rainfall_mean_dest rainfall_sd_dest) , fe cluster(FE_origdestprod)
					estimates store c6
					estadd local FE_origdestprod "Yes"
					estadd local FE_prodmon "Yes"
					estadd scalar r2_treb e(r2)
					
				xi: xtivreg2 ln_quantity i.FE_prodmon (ln_price_dest ln_price_orig ln_price_destXtheta_orig = rainfall_* thetaX*) , fe cluster(FE_origdestprod)
					estimates store c8
					estadd local FE_origdestprod "Yes"
					estadd local FE_prodmon "Yes"		
					estadd scalar r2_treb e(r2)
					
	* Making the Table
		lab var ln_price_dest "Log origin price (2000 PHP)"
		lab var ln_price_orig "Log destination price (2000 PHP)"
		lab var ln_price_destXtheta_orig "Log destination price * origin producer heterogeneity"
		
		estout c1 c2 c3 c4 using puzzle_hetero_$date.tex, ///
			type style(tex) replace title("Trade flows, prices, and producer heterogeneity") ///
			prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:puzzle_hetero} ///
			\begin{tabular}{lllll}) ///
			posthead("\hline") prefoot("\hline") ///
			varlabels(_cons "Constant") wrap ///
			cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
			stats(FE_origdestprod r2 N, fmt(%6.3f %6.3f %6.0f)  labels("Importer-origin-Product FE" "R-squared" "Observations")) ///
			starlevels(* .1 ** .05 *** .01) collabels(none) mlabels("OLS" "2SLS" "OLS" "2SLS", lhs("Dep. var.: Log quantity exported")) ///
			drop(temp* _cons _I* o.*, relax) ///
			label numbers ///
			postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} The dependent variable is the log quantity exported.  ///
				Each observation is an origin-importer-year-month-product quintuplet.  Because the quantity traded is observed annually while prices are observed monthly, standard errors are clustered at the origin-importer-product level. ///
				In the 2SLS columns, the origin and destination prices are instrumented with the mean and standard deviation of monthly rainfall in their respective locations.  ///
				The origin producer heterogeneity is a province-crop specific Pareto shape parameter estimated from the 1990 Agricultural Census micro-data; lower values indicate greater heterogeneity across farmers in land allocated to a particular crop. /// 
				Clustered standard errors are reported in parentheses.  Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. ///
			\end{minipage} \end{table} ) substitute($ \$)		
	
		estout c5 c6 c7 c8 using puzzle_hetero2_$date.tex, ///
			type style(tex) replace title("Trade flows, prices, and producer heterogeneity") ///
			prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:puzzle_hetero2} ///
			\begin{tabular}{lllll}) ///
			posthead("\hline") prefoot("\hline") ///
			varlabels(_cons "Constant") wrap ///
			cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
			stats(FE_origdestprod FE_prodmon r2_treb N, fmt(%6.3f %6.3f %6.3f %6.0f)  labels("Origin-Destination-Commodity FE" "Commodity-Month FE" "R-squared (within)" "Observations")) ///
			starlevels(* .1 ** .05 *** .01) collabels(none) mlabels("OLS" "2SLS" "OLS" "2SLS", lhs("Dep. var.: Log quantity exported")) ///
			drop(temp* _cons _I* o.*, relax) ///
			label numbers ///
			postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} The dependent variable is the log quantity exported.  ///
				Each observation is an origin-importer-year-month-product quintuplet.  Because the quantity traded is observed annually while prices are observed monthly, standard errors are clustered at the origin-importer-product level. ///
				In the 2SLS columns, the origin and destination prices are instrumented with the mean and standard deviation of monthly rainfall in their respective locations.  ///
				The origin producer heterogeneity is a province-crop specific Pareto shape parameter estimated from the 1990 Agricultural Census micro-data; lower values indicate greater heterogeneity across farmers in land allocated to a particular crop. /// 
				Standard errors clustered at the origin-destination-commodity level are reported in parentheses.  Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. ///
			\end{minipage} \end{table} ) substitute($ \$)				
		
