* This do-file examines the farmer-trader transactions
* written by Treb on 6/4/11

clear
global date = "092011"
global dropbox = "C:\Users\Treb\Documents\My Dropbox"
global dir = "$dropbox\Research\Trade\Information\Empirics\Farmer Trader Transactions"
global dir_phone = "$dropbox\Research\Data\Philippines\Cell phones\Towers"
global dir_price = "$dropbox\Research\Data\Philippines\FPS request"
global dir_prov = "$dropbox\Research\Data\Philippines"
global dir_land = "$dropbox\Research\Data\Philippines\Census of Agriculture\1991"
global dir_fixed = "$dropbox\Research\Trade\Information\Empirics\Farmer Trader Fixed Cost"

estimates clear

cd "$dir"
cap log close
log using cellphones_$date.log, replace

*** Loading the data
			
	* loading cell phone towers
		clear
		use "$dir_phone\cell_access_060311.dta"
		sort province_id year month
		by province_id: gen temp = towers==1 & towers[_n-1] ==0
		by province_id: gen tower_after = (temp==1 | temp[_n-1]==1 | temp[_n-2]==1 | temp[_n-3]==1 | temp[_n-4]==1 | temp[_n-5]==1)
		by province_id: gen tower_before = (temp[_n+1]==1 | temp[_n+2]==1 | temp[_n+3]==1 | temp[_n+4]==1 | temp[_n+5]==1 | temp[_n+6]==1)
		drop temp
		lab var tower_after "Dummy equal to one if 6 months after tower was built"
		lab var tower_before "Dummy equal to one if 6 months before tower was built"
		sort province_id year month
		tempfile temp_phone
		save `temp_phone', replace

	* loading farmer transaction data
		clear
		use "$dir_price\cleaned_data_013111.dta"
		gen year = year(date)
		gen month = month(date)
		
	* cutting down to the relevant sample
			
		* cutting outliers
		keep if quantity>0 & quantity<100000
		
		* dropping animals
		drop if word(com_name,1)=="CARABAO"
		drop if word(com_name,1)=="CHICKEN"
		drop if word(com_name,1)=="DUCK"
		drop if word(com_name,1)=="HOGS"
		drop if word(com_name,1)=="GOAT"
		
	* merging on phone towers
		sort province_id year month
		merge province_id year month using `temp_phone'
		tab _merge
		keep if _merge==3
		drop _merge
		
*** Creating the variables
	
	cap drop ln_*
	gen ln_price = ln(price)
	gen ln_quantity = ln(quantity)
	
	* Phone
		cap drop any_phone
		cap drop ln_quantityXany_phone
		
		gen any_phone = towers>0
		replace any_phone = . if towers==.
		gen ln_quantityXany_phone = any_phone*ln_quantity
	
	* freight
		cap drop any_freight
		cap drop any_freightXany_phone
		
		gen any_freight = freight>0 & freight<.
		gen any_freightXany_phone = any_freight*any_phone
		
	* Fixed effects
		cap drop FE*
		egen FE_provcomyr = group(province_id year com_name)
		egen FE_common = group(com_name year month)
		egen FE_provcommon = group(province_id year month com_name) /* within a monthly market */
		
		* rolling window fixed effect
		cap drop temp* 
		gen temp = tower_after==1 | tower_before==1
		egen FE_provcomwindow = group(province_id com_name temp) /* so dummy variable if in rollowing window */
	
*** Regressions
	estimates clear
	
	** Whether or not a farmer searches (i.e. incurs freight costs)
						
		sum any_freight
		local mean_freight = r(mean)
		
		xtset FE_provcommon
		xtreg any_freight ln_quantity, fe cluster(FE_provcommon)
			estimates store a1, title("OLS")
			estadd local FEprovcomyr "Yes"
			estadd local FEcommon "Yes"
			estadd local FEprovcommon "Yes"
			estadd scalar mean_dep `mean_freight'
			estadd scalar r2_treb e(r2_w)
			estimates save farmer_$date_a1, replace
			
		gpreg any_freight any_phone ln_quantity ln_quantityXany_phone, i(FE_provcomyr) j(FE_common) a(3)
			estimates store a2, title("OLS")
			estadd local FEprovcomyr "Yes"
			estadd local FEcommon "Yes"
			estadd local FEprovcommon "No"
			estadd scalar r2_treb e(r2)
			estadd scalar mean_dep `mean_freight'
			estimates save farmer_$date_a2, replace

		xtset FE_provcommon		
		xtreg any_freight ln_quantity ln_quantityXany_phone, fe cluster(FE_provcommon)
			estimates store a3, title("OLS")
			estadd local FEprovcomyr "Yes"
			estadd local FEcommon "Yes"		
			estadd local FEprovcommon "Yes"
			estadd scalar mean_dep `mean_freight'
			estadd scalar r2_treb e(r2_w)
			estimates save farmer_$date_a3, replace
			
	** Whether or not a farmer searches (window around when tower is built)
		preserve
		keep if tower_before==1 | tower_after==1
		cap drop FE*
		egen FE_common = group(month year com_name)
		egen FE_provcom = group(province_id com_name)
		egen FE_provcommon = group(province_id com_name year month)
		
		xtset FE_provcommon
		xtreg any_freight ln_quantity, fe cluster(FE_provcommon)
		gpreg any_freight any_phone ln_quantity ln_quantityXany_phone, i(FE_provcom) j(FE_common)
		xtreg any_freight ln_quantity ln_quantityXany_phone, fe cluster(FE_provcommon)
		
		restore
		
	
		
*** Making table

	lab var ln_quantity "Log quantity sold"
	lab var any_phone "Mobile phone access"
	lab var ln_quantityXany_phone "Mobile phone access*log quantity sold"
	lab var any_freight "Searched for a trader"
	lab var any_freightXany_phone "Mobile phone access*searched for a trader"
	
	estout a* using farmer_$date.tex, ///
		type style(tex) replace title("Farmer search and the impact of mobile phones") ///
		prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:farmer}  ///
		\begin{tabular}{l*{@M}l}) ///
		posthead("\hline") prefoot("\hline") ///
		varlabels(_cons "Constant")  wrap ///
		cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
		stats(FEprovcomyr FEcommon FEprovcommon mean_dep r2_treb N, fmt(%6.3f %6.3f %6.3f %6.3f %6.3f %6.0f) labels("Province-Commodity-Year FE" "Commodity-Year-Month FE" "Province-Commodity-Year-Month FE" "Mean of Dep. Var." "R-squared (within)" "Observations")) ///
		starlevels(* .1 ** .05 *** .01) collabels(none)  mlabels( , lhs("Dep. var.: farmer searched for trader")) ///
		drop(temp* _I* _cons, relax) ///
		label numbers ///
		postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} The dependent variable is an indicator variable equal to one if the farmer searched for a trader.  ///
			The unit of observation is a farmer sale in a province-commodity-year-month. ///
			Mobile phone access is an indicator variable equal to one if there existed a cell tower in the province in that particular month. ///
			Standard errors clustered at the province-commodity-year-month are the reported in parentheses.  Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. ///
		\end{minipage} \end{table} ) substitute($ \$ !$ $)	
	
	
			
