*** This do-file computes the fraction of the observed variance in yields and prices that is explained by weather shocks, province fixed effects, and year fixed effects
** written by treb on 6/11/11

* updated on jan 16 2014 to account for monthly prices

clear
cap log close
log using rainfall_priceyields_$date.log, replace

* This do file creates predicted prices of agricultural goods from rainfall shocks
* written by Treb on Sept 16, 2010

clear
global date = "140116"
global dropbox = "C:\Users\dwi902\Dropbox"
global dir = "$dropbox\Research\Trade\Information\Empirics\Empirical context"
global dir_price = "$dropbox\Research\Data\Philippines\Production and Price Data\Monthly Prices"
global dir_rain = "$dropbox\Research\Data\Philippines\Rainfall"
global dir_dist = "$dropbox\Research\Data\Philippines\Geographic Data"
global dir_prov = "$dropbox\Research\Data\Philippines"
global dir_island = "$dropbox\Research\Data\Philippines\Geographic Data"
global dir_land = "$dropbox\Research\Data\Philippines\Provincial Data\Land Use"
global dir_quantity = "$dropbox\Research\Data\Philippines\Provincial Data\Crop Production"
global dir_provdata = "$dropbox\Research\Data\Philippines\Provincial Data"
global dir_sample = "$dropbox\Research\Trade\Information\Empirics\Reduced Form"
global dir_id = "$dropbox\Research\Data\Philippines"
global dir_prodrice = "$dropbox\Research\Data\Philippines\Production and Price Data\Rice and Corn\Quantity"
global dir_arearice = "$dropbox\Research\Data\Philippines\Production and Price Data\Rice and Corn\Area"

cd "$dir"

** Making a program that does decompositions
	cap prog drop treb_shapley
	prog treb_shapley
		qui: desc `2', varlist
		local temp_2 = r(varlist)
		qui desc `3', varlist
		local temp_3 = r(varlist)
		qui reg `1' `2' `3'
		shapley2, stat(r2) group("`temp_2'", "`temp_3'")
	end

	cap prog drop treb_shapley3
	prog treb_shapley3
		qui: desc `2', varlist
		local temp_2 = r(varlist)
		qui desc `3', varlist
		local temp_3 = r(varlist)
		qui desc `4', varlist
		local temp_4 = r(varlist)
		qui reg `1' `2' `3' `4'
		shapley2, stat(r2) group("`temp_2'", "`temp_3'", "`temp_4'")
	end

	cap prog drop treb_shapley4
	prog treb_shapley4
		qui: desc `2', varlist
		local temp_2 = r(varlist)
		qui desc `3', varlist
		local temp_3 = r(varlist)
		qui desc `4', varlist
		local temp_4 = r(varlist)
		qui desc `5', varlist
		local temp_5 = r(varlist)
		qui reg `1' `2' `3' `4' `5'
		shapley2, stat(r2) group("`temp_2'", "`temp_3'", "`temp_4'", "`temp_5'")
	end

** Loading rainfall

*** Step #1: Loading rainfall data (raw)

clear
use "$dir_rain\province_rain_030911.dta"

	* Converting into monthly measures
	gen month = month(date)
	gen year = year(date)
	bysort province_id year month: egen rainfall_mean = mean(rainfall_predict)
	bysort province_id year month: egen rainfall_sd = sd(rainfall_predict)
	bysort province_id year month: keep if _n==1
	lab var rainfall_mean "Mean daily rainfall over the month"
	lab var rainfall_sd "Std.dev. of daily rainfall over the month"
	drop rainfall_predict date
	
	* getting into order
	keep month year province_id province_name rainfall_mean rainfall_sd
	order province_id province_name year month
	sort province_id year month
	tempfile temp_rain
	save `temp_rain', replace
	
*** Step #2: Predicting production of rice and corn
	* getting province_id's 
		clear
		use "$dir_id\province_id_MASTER.dta"
		keep province_id province_name
		sort province_name
		tempfile temp_prov
		save `temp_prov', replace
	
	clear
	use "$dir_prodrice\1994 - 2009 rice and corn (cleaned).dta"
		destring quantity, force replace
		sort province_name year quarter crop
	
	preserve
		clear
		use "$dir_arearice\1994 - 2009 rice and corn (cleaned).dta"
		destring area, force replace
		sort province_name year quarter crop
		tempfile temp_area
		save `temp_area', replace
	restore
	
	merge province_name year quarter crop using `temp_area'
		tab _merge
		drop _merge
	
	* getting agprod_name
		gen agprod_name = "Corn" if crop == "Corn"
		replace agprod_name = "Rice" if crop =="Palay"
		keep if agprod_name ~= ""
		bysort province_name year quarter agprod_name: assert _n==1
		drop crop
	
	* getting month
		expand 3
		bysort agprod_name province_name year quarter: gen month = (quarter-1)*3 + _n
		bysort agprod_name province_name year quarter: gen temp_month = _n
		
	* getting province id
		replace province_name = upper(trim(province_name))
			replace province_name = "OCCIDENTAL MINDORO" if province_name == "MINDORO OCCIDENTAL"
			replace province_name = "ORIENTAL MINDORO" if province_name == "MINDORO ORIENTAL"
			replace province_name = "WESTERN SAMAR" if province_name == "SAMAR"
			replace province_name = "DAVAO DEL NORTE" if province_name == "DAVAO PROVINCE"
			replace province_name = "COTABATO" if province_name == "NORTH COTABATO"
		keep province_name year month agprod_name quantity temp_month quarter area
		order province_name agprod_name year month
		sort province_name agprod_name year month
		merge province_name using `temp_prov'
		tab _merge
		keep if _merge==3
		drop _merge
		
	* renaming and preparing for merge
		sort province_id year month agprod_name
		merge province_id year month using `temp_rain'
		tab _merge
		keep if _merge==3
		drop _merge
		sort province_id year month
		tempfile temp_yield
		save `temp_yield', replace
		
	** getting back to one observation per quarter
		egen temp_id = group(province_id agprod_name year quarter)
		drop month
		reshape wide rainfall_mean rainfall_sd, i(temp_id) j(temp_month) /* so now we have mean and sd of rainfall in each month in each quarter */
		drop temp_id
	
	** Decomposition of variance
		
		* fixed effects 
			cap drop FE*
			egen FE_cyq = group(agprod_name year quarter)
			egen FE_cy = group(agprod_name year)
			egen FE_pc = group(province_id agprod_name)
			levelsof agprod_name, local(agprod)
			
		* rainfall (interacted with crop)
			cap drop C*
			foreach a of local agprod {
				foreach var of var rainfall* {
					gen C`a'_`var' = 0
					replace C`a'_`var' = `var' if agprod_name=="`a'"
				}
			}
			
		* logs
			cap drop ln_*
			gen ln_yield = ln(quantity/area)
			gen ln_quantity = ln(quantity)
			foreach var of var C* {
				gen ln_`var' = ln(`var')
				replace ln_`var' = 0 if `var'==0
			}
			
		* Question #1: Within quarter, how much variance is there in yields?
			cap drop temp*
			bysort FE_cyq: egen temp_var = sd(ln_yield)
			bysort FE_cyq: gen temp = _n==1
			sum temp_var if temp==1
			* Answer: 42.7% log variation of yields within quarter		

		* Question #2: Within province, how much variance is there in yields across time?
			cap drop temp*
			bysort FE_pc: egen temp_var = sd(ln_yield)
			bysort FE_pc: gen temp = _n==1
			sum temp_var if temp==1
			* Answer: 26.2% log variation of yields within quarter		
			
		* Question 3: Within province-year, how much variation is there across quarters?
			cap drop temp*
			bysort FE_cy FE_pc: egen temp_var = sd(ln_yield)
			bysort FE_cy FE_pc: gen temp = _n==1
			sum temp_var if temp==1
			* Answer: 14.76% log variation of yields within year across quarters

		* Question #4: What explains the difference in yields across space and time?
			xi i.FE_pc i.FE_cyq
			treb_shapley3 ln_yield ln_C* _IFE_pc* _IFE_cyq*
		
*** Step #3: Predicting wholesale prices
	clear
	
	** Loading other data
	
		** Prices
			clear
			use "$dir_price\monthly_wholesale_prices_cleaned.dta"
			gen year = real(substr(date,1,4))
			gen month = month(date(date,"YM"))
			drop if month==.
			
			* averaging prices within agprod_name
				bysort province_id year month agprod_name: egen price_mean = mean(price)
				
			* one observation
				bysort province_id year month agprod_name: keep if _n==1
				keep province_id province_name year month agprod_name price_mean
				ren price_mean price
				
			* converting to real
				foreach var of var price* {
					replace `var' = `var'/(0.768) if year==1995
					replace `var' = `var'/(0.843) if year==1996
					replace `var' = `var'/(0.871) if year==1997
					replace `var' = `var'/(0.943) if year==1998
					replace `var' = `var'/(0.985) if year==1999
					replace `var' = `var'/(1) if year==2000
					replace `var' = `var'/(1.047) if year==2001
					replace `var' = `var'/(1.069) if year==2002
					replace `var' = `var'/(1.093) if year==2003
					replace `var' = `var'/(1.116) if year==2004
					replace `var' = `var'/(1.239) if year==2005
					replace `var' = `var'/(1.307) if year==2006
					replace `var' = `var'/(1.350) if year==2007
					replace `var' = `var'/(1.533) if year==2008
					replace `var' = `var'/(1.6423) if year==2009
				}
				
			* saving
				sort province_id year month agprod_name
				tempfile temp_price
				save `temp_price', replace
				
			* getting province id
				replace province_name = upper(trim(province_name))
					replace province_name = "OCCIDENTAL MINDORO" if province_name == "MINDORO OCCIDENTAL"
					replace province_name = "ORIENTAL MINDORO" if province_name == "MINDORO ORIENTAL"
					replace province_name = "WESTERN SAMAR" if province_name == "SAMAR"
					replace province_name = "DAVAO DEL NORTE" if province_name == "DAVAO PROVINCE"
					replace province_name = "COTABATO" if province_name == "NORTH COTABATO"
				keep province_name year month agprod_name price
				order province_name agprod_name year month
				sort province_name agprod_name year month
				merge province_name using `temp_prov'
				keep if _merge==3
				drop _merge
				
			* renaming and preparing for merge
				sort province_id year month agprod_name
				tempfile temp_frac
				save `temp_frac', replace
			
		* only keeping observations with prices
			keep if price<.
			keep if agprod_name=="Rice" | agprod_name=="Corn"
			
		* merging on rainfall
			sort province_id year month
			merge province_id year month using `temp_rain'
			tab _merge
			tab year if _merge==1 /* okay so it's just the new prices */
			keep if _merge==3
			drop _merge
			
		* * merging on yields
			* sort province_id year month
			* merge province_id year month using `temp_yield'
			* tab _merge
			* drop if _merge==2
			* drop _merge
					
		* FE
			cap drop FE*
			egen FE_cym = group(agprod_name year month)
			egen FE_cy = group(agprod_name year)
			egen FE_cp = group(agprod_name province_id)
			
		* rainfall (interacted with crop)
			levelsof agprod_name, local(agprod)
			cap drop C*
			foreach a of local agprod {
				foreach var of var rainfall* {
					gen C`a'_`var' = 0
					replace C`a'_`var' = `var' if agprod_name=="`a'"
				}
			}
			
		* logs
			cap drop ln_*
			gen ln_price = ln(price)
			foreach var of var C* {
				gen ln_`var' = ln(`var')
				replace ln_`var' = 0 if `var'==0
			}
			
		* Question #1: Within month, how much variance is there in prices? Answer: 15%
			cap drop temp*
			bysort FE_cym: egen temp_sd = sd(ln_price) 
			bysort FE_cym: gen temp = _n==1
			sum temp_sd if temp==1
		
		* Question #2: Within a province, how much variance is there in prices? Answer: 16%
			cap drop temp*
			bysort FE_cp: egen temp_sd = sd(ln_price) 
			bysort FE_cp: gen temp = _n==1
			sum temp_sd if temp==1		
		
		* Question #3: Within year, how much variation is there in prices within a province-crop? Answer: 7%
			cap drop temp*
			bysort FE_cy FE_cp: egen temp_sd = sd(ln_price) 
			bysort FE_cy FE_cp: gen temp = _n==1
			sum temp_sd if temp==1		
			
		* Question 4: Where does the variation in prices come from?
			xi i.FE_cp i.FE_cym
			treb_shapley3 ln_price ln_C* _IFE_cp* _IFE_cym*

			
			
			
		* Price rankings
			bysort FE_cym: cumul price, generate(price_rank)
			
				preserve
				cap drop date
				gen date = monthly(string(month) + "/" + string(year), "MY")
				cap drop temp*
				egen temp_id = group(province_id agprod_name)
				keep price_rank temp_id date
				reshape wide price_rank, i(temp_id) j(date)
				qui corr price_rank*
				matrix define A = r(C)
				drop temp_id price_rank*
				svmat A, names(col)
				outsheet price_rank* using priceranks_corr_$date.out, nonames nolabel
				restore
				
		
				
				
asdfa
			
			
			treb_shapley price_rank ln_C* _IFE_cp*
			
			cap drop L*
			sort agprod_name province_id year month
			bysort agprod_name province_id year: gen Lprice_rank = price_rank[_n-1] if month[_n-1] + 1 == month[_n]
			reg price_rank Lprice_rank
			areg price_rank, a(FE_cp)
			areg price_rank Lprice_rank, a(FE_cp)

		* What percent of the variation of the ranking within a province-commodity over time can be explained by variation in rainfall?
			* first, we net out the province-commodity FE
				cap drop resid*
				foreach var of var price_rank ln_C* {
					qui xi: reg `var' i.FE_cp
					predict resid_`var', r
				}
			
			* now we regress the residuals on each other
				reg resid_price_rank resid_ln_C*
		
		* Question #3: Of the spatial variation, how much can be explained by rainfall and province FE?
			* Answer: XX% by rainfall and XX% by province FE
		
			* de-meaning by time period
					cap drop hat*
					foreach var of var ln_* {
						qui: xi: reg `var' i.FE_cym
						predict hat_`var', xb
					}
			
			
			
			* decomposition of within quarter spatial variation into rainfall, province FE, and other
				qui xi: reg hat_ln_price hat_ln_C* i.FE_cp
					local size = e(rank) - 4 - 1
					disp `size'
				qui xi: ineqrbd hat_ln_price hat_ln_C* i.FE_cp, noreg
					local contrib_rain = 0
					local k = 0
					forvalues j=1/4 {
						local k = `k' + 1
						local contrib_rain = `contrib_rain' + real(r(sf_Z`k'))
						}
					local contrib_prov= 0
					forvalues j=1/`size' {
						local k = `k' + 1
						local contrib_prov = `contrib_prov' + real(r(sf_Z`k'))
						}				
					local contrib_unex = 1 - `contrib_rain' - `contrib_prov'
					disp "Contribution of rain: `contrib_rain'"
					disp "Contribution of prov: `contrib_prov'"
					disp "Unexplained contrib.: `contrib_unex'"	
		
		* Question #4: How much do the relative prices change over time?
			
			
			
			asdfa
			
			
	
			
	
*** Seeing how the relative ranking of prices change over time
	cap log close
	log using price_corr_$date.log, replace

	bysort year crop: cumul price, generate(price_cdf)

	cap drop FE_*	
	egen FE_prodprov = group(crop province_id)
	xtset FE_prodprov year
	reg price_cdf L.price_cdf
	xtreg price_cdf L.price_cdf, fe
	
	** matrix of correlations
	preserve
		cap drop FE_*
		egen FE_prodprov = group(crop province_id)
		keep crop province_id FE_prodprov year price_cdf
		reshape wide price_cdf, i(FE_prodprov) j(year)
		corr price_cdf1995-price_cdf2009
		
	restore
	
*** How much of the change in ranking can be explained by rainfall variables?

	* de-meaning the rainfall measures by year
	foreach var of var rainfall_* {
		cap drop temp*
		bysort year: egen temp = mean(`var')
		replace `var' = `var' - temp
		drop temp
	}
	
	* interacting each rainfall measure with the crop
	cap drop FE*
	egen FE_crop = group(crop)
	levelsof FE_crop, local(crop)
	foreach c of local crop {
		foreach var of var rainfall_* {
			gen crop_`c'X`var' = 0
			replace crop_`c'X`var' = `var' if FE_crop==`c'
		}
	}
	
	* regression
	cap drop FE*
	egen FE_cropprov = group(crop province_id)
	areg price_cdf crop_*, a(FE_cropprov)
	local r2 = e(r2)
	local r2_a = e(r2_a)
	
	disp "R-squared: `r2'; adjusted R-squared: `r2_a'"
	
log close
exit

