** This do-file presents several trade patterns in the data

clear
cap log close
set more off

global date = "110813"
* global dropbox = "C:\Documents and Settings\Treb Allen\My Documents\My Dropbox"
* global dropbox = "C:\Users\Treb\Documents\My Dropbox"
global dropbox = "C:\Users\dwi902\Dropbox"
global dir = "$dropbox\Research\Trade\Information\Empirics\Philippines Trade Flows"
global dir_trade = "$dropbox\Research\Data\Philippines\Agricultural Trade"
global dir_sample = "$dropbox\Research\Trade\Information\Empirics\Reduced Form"
global dir_phone = "$dropbox\Research\Data\Philippines\Cell phones\Towers"

cd "$dir"
log using tradepatterns_$date.log, replace
		
** By province / year
	
	clear
	use "$dir_trade\agtrade_prov.dta"
				
	* getting one observation per crop-prov-4th quarter and whether it imported, exported, and who had cell phones
		gen trade = quantity>0
		
		bysort province_orig_id agprod_name year: egen export = max(trade)
		bysort province_dest_id agprod_name year: egen import = max(trade)
		
		preserve 
			bysort province_orig_id agprod_name year: keep if _n==1
			keep province_orig_id agprod_name year export
			ren province_orig_id province_id
			sort province_id agprod_name year
			tempfile temp_orig
			save `temp_orig', replace
			
		restore
		preserve
			bysort province_dest_id agprod_name year: keep if _n==1
			keep province_dest_id agprod_name year import
			ren province_dest_id province_id
			sort province_id agprod_name year	
			tempfile temp_dest
			save `temp_dest', replace
		restore

		* creating a list of all province-crop-years
			preserve
			bysort province_orig_id: keep if _n==1
			keep province_orig_id
			tempfile temp_prov
			save `temp_prov', replace
			restore
			
			preserve
			bysort agprod_name: keep if _n==1
			keep agprod_name
			tempfile temp_agprod
			save `temp_agprod', replace
			restore
			
			bysort year: keep if _n==1
			keep year
			tempfile temp_year
			save `temp_year', replace
			
			cross using `temp_agprod'
			cross using `temp_prov'
			
			ren province_orig_id province_id
			order province_id agprod_name year
			sort province_id agprod_name year
			merge province_id agprod_name year using `temp_orig'
			tab _merge
			drop _merge
			sort province_id agprod_name year
			merge province_id agprod_name year using `temp_dest'
			tab _merge
			drop _merge
			
	* merging on cell phone data
			
		* loading cellphone data
			preserve
				clear
				use "$dir_phone\cell_access_060311.dta"
				keep province_id year month towers 
				bysort province_id year: egen temp = max(towers)
				drop towers
				ren temp towers
				bysort province_id year: keep if _n==1
				sort province_id year
				tempfile temp_phone
				save `temp_phone', replace
			restore
			
		* merging
			sort province_id year
			merge province_id year using `temp_phone'
			tab _merge
			keep if _merge==3
			drop _merge
			
			
	* let's create different categories
		
		gen only_export = (export==1 & import~=1)
		gen only_import = (import==1 & export~=1)
		gen both_exim = (export==1 & import==1)
		gen neither = export~=1 & import~=1
		gen phone = towers>0
		
	* creating a total category
		local n = _N + 2
		set obs `n'
		replace agprod_name = "Total" if _n>=_N-1
		replace phone = 0 if _n==_N-1
		replace phone = 1 if _n==_N
		foreach var of var only_export only_import both_exim neither {
			qui sum `var' if phone==0
			local temp = r(mean)
			replace `var' = `temp' if _n==_N-1
			qui sum `var' if phone==1
			local temp = r(mean)
			replace `var' = `temp' if _n==_N
			
		}
		
	* let's make tables and figures
		tabstat both_exim only_export only_import neither, by(phone)
		xi: areg both_exim phone i.agprod_name, a(province_id)
			estimates store a1
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "No"
			estadd local sample "All provinces"	
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'	
			
		xi: areg both_exim phone i.agprod_name i.year, a(province_id)	
			estimates store a2
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "Yes"
			estadd local sample "All provinces"	
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'	
			
		xi: areg both_exim phone i.agprod_name if neither==0, a(province_id)
			estimates store a3
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "No"
			estadd local sample "Trading provinces"	
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'	
			
		xi: areg both_exim phone i.agprod_name i.year if neither==0, a(province_id)	
			estimates store a4
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "Yes"		
			estadd local sample "Trading provinces"	
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'	
			
		graph bar (mean)  both_exim only_export only_import, ///
			over(agprod_name, sort(agprod_name) lab(angle(45)) gap(10))  stack xsize(7) scale(0.8) ///
			title("Province-province, annual") ///
			bar(1, color(blue)) bar(2, color(blue*0.6)) bar(3, color(blue*0.3)) bar(4, color(blue*0.1)) ///
			graphregion(fcolor(gs16)) yscale(range(0 0.35)) ///
			ytitle("Fraction of provinces")  ///
			legend(label(1 "Import & Export") label(2 "Export only") label(3 "Import only") r(1)) ///
			saving(puzzle_2way_prov_$date, replace)	
		graph export puzzle_2way_prov_$date.pdf, replace	
			
	
** By port / 4th quarter
	
	clear
	use "$dir_trade\agtrade_port.dta"
				
	* getting one observation per crop-port-4th quarter and whether it imported, exported, and who had cell phones
		gen trade = quantity_4>0
		
		bysort port_orig_id agprod_name year: egen export = max(trade)
		bysort port_dest_id agprod_name year: egen import = max(trade)
		
		preserve 
			bysort port_orig_id agprod_name year: keep if _n==1
			keep port_orig_id agprod_name year export
			ren port_orig_id port_id
			sort port agprod_name year
			tempfile temp_orig
			save `temp_orig', replace
			
		restore
		preserve
			bysort port_dest_id agprod_name year: keep if _n==1
			keep port_dest_id agprod_name year import
			ren port_dest_id port_id
			sort port agprod_name year	
			tempfile temp_dest
			save `temp_dest', replace
		restore

		* creating a list of all port-crop-years
			preserve
			bysort port_orig_id: keep if _n==1
			keep port_orig_id province_orig_id
			tempfile temp_port
			save `temp_port', replace
			restore
			
			preserve
			bysort agprod_name: keep if _n==1
			keep agprod_name
			tempfile temp_agprod
			save `temp_agprod', replace
			restore
			
			bysort year: keep if _n==1
			keep year
			tempfile temp_year
			save `temp_year', replace
			
			cross using `temp_agprod'
			cross using `temp_port'
			
			ren port_orig_id port_id
			ren province_orig_id province_id
			order port_id agprod_name year
			sort port_id agprod_name year
			merge port_id agprod_name year using `temp_orig'
			tab _merge
			drop _merge
			sort port_id agprod_name year
			merge port_id agprod_name year using `temp_dest'
			tab _merge
			drop _merge
			
	* merging on cell phone data
			
		* loading cellphone data
			preserve
				clear
				use "$dir_phone\cell_access_060311.dta"
				keep province_id year month towers 
				bysort province_id year: egen temp = max(towers)
				drop towers
				ren temp towers
				bysort province_id year: keep if _n==1
				sort province_id year
				tempfile temp_phone
				save `temp_phone', replace
			restore
			
		* merging
			sort province_id year
			merge province_id year using `temp_phone'
			tab _merge
			keep if _merge==3
			drop _merge
			
			
		* let's create different categories
			
			gen only_export = (export==1 & import~=1)
			gen only_import = (import==1 & export~=1)
			gen both_exim = (export==1 & import==1)
			gen neither = export~=1 & import~=1
			gen phone = towers>0
			
	* creating a total category
		local n = _N + 2
		set obs `n'
		replace agprod_name = "Total" if _n>=_N-1
		replace phone = 0 if _n==_N-1
		replace phone = 1 if _n==_N
		foreach var of var only_export only_import both_exim neither {
			qui sum `var' if phone==0
			local temp = r(mean)
			replace `var' = `temp' if _n==_N-1
			qui sum `var' if phone==1
			local temp = r(mean)
			replace `var' = `temp' if _n==_N
			
		}
		
	* let's make tables and figures
		tabstat both_exim only_export only_import neither, by(phone)
		xi: areg both_exim phone i.agprod_name, a(port_id)
			estimates store b1
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "No"
			estadd local sample "All ports"
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'
			
		xi: areg both_exim phone i.agprod_name i.year, a(port_id)	
			estimates store b2
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "Yes"
			estadd local sample "All ports"
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'
			
		xi: areg both_exim phone i.agprod_name if neither==0, a(port_id)
			estimates store b3
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "No"
			estadd local sample "Trading ports"
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'
			
		xi: areg both_exim phone i.agprod_name i.year if neither==0, a(port_id)	
			estimates store b4
			estadd local FE_agprod "Yes"
			estadd local FE_prov "Yes"
			estadd local FE_year "Yes"	
			estadd local sample "Trading ports"	
			qui sum both_exim if e(sample)
			local dmean = r(mean)
			estadd scalar dmean `dmean'		
			
		graph bar (mean)  both_exim only_export only_import, ///
			over(agprod_name, sort(agprod_name) lab(angle(45)) gap(10))  stack xsize(7) scale(0.8) ///
			title("Port-port, 4th quarter") ///
			bar(1, color(blue)) bar(2, color(blue*0.6)) bar(3, color(blue*0.3)) bar(4, color(blue*0.1)) ///
			graphregion(fcolor(gs16)) yscale(range(0 0.35)) ///
			ytitle("Fraction of ports")  ///
			legend(label(1 "Import & Export") label(2 "Export only") label(3 "Import only") r(1)) ///
			saving(puzzle_2way_port_$date, replace)	
		graph export puzzle_2way_port_$date.pdf, replace	
	
*** combining graphs
	grc1leg puzzle_2way_prov_$date.gph puzzle_2way_port_$date.gph, ///
		cols(1) legendfrom(puzzle_2way_prov_$date.gph) ///
		imargin(zero) scale(0.8) ///
		graphregion(fcolor(gs16)) plotregion(ilcolor(black)) ///
		saving(puzzle_2way_combine_$date.gph, replace)
	graph export puzzle_2way_combine_$date.pdf, replace
	
*** Making the table
	lab var phone "Mobile phone access"
	estout a1 a3 b1 b3 using tradepatternsphone_$date.tex, ///
		type style(tex) replace title("Simultaneously importing/exporting and mobile phone access") ///
		prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:tradepatternsphone} ///
		\begin{tabular}{lllll}) ///
		posthead("\hline") prefoot("\hline") ///
		varlabels(_cons "Constant")  ///
		cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
		stats(FE_agprod FE_prov sample dmean r2 N, fmt(%6.3f %6.3f %6.3f %6.3f %6.3f %6.0f) ///
		labels("Commodity FE" "Province/Port FE" "Sample" "Mean of dep. variable" "R-squared" "Observations")) ///
		mgroups("Province-province, annual" "Port-port, 4th quarter", lhs("Dep var.: Simultaneously imported ++ exported") pattern(1 0 1 0) span prefix(\multicolumn{@span}{c}{) suffix(})) ///
		mlabels(none) starlevels(* .1 ** .05 *** .01) collabels(none) ///
		drop(temp* _cons _I* o.*, relax) ///
		label numbers ///
		postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} Ordinary least squares. Each observation is a province-year (columns 1-4) or port-4th quarter (columns 5-8) pair.  ///
			  The dependent variable is an indicator variable equal to one if a province/port both imported and exported a given commodity in a given year/4th quarter. ///
			  Mobile phone access is an indicator variable equal to one if a province/port has a civilian cell phone tower in operation in a given year. ///
			Standard errors are reported in parentheses. Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. ///
		\end{minipage} \end{table} ) substitute(++ \& $ \$ !$ $ ~ .\ % \%)	
	

		
log close
exit

	