function integ = Kfun_integ_082313(p_orig,p_dest,s,theta)

    % this function takes a list of destination prices and calculates the
    % integral between the origin price and the destination price
    % note: destination prices are net of transportation costs
    
    % there are two methods: curvature integration and riemann integration.
    % It turns out the latter is approximately 300x faster.
 
    % step #1: define the distribution of prices
        F_j = @(x) (ones(size(p_dest))*x)>=(p_dest*ones(size(x)));
        F = @(x) sum((s*ones(size(x))).*F_j(x),1);
    
        
% % Curvature approximation integration    
%     tic
%     abstol = 1e-10; % absolute tolerance of the integral
%     reltol = 1e-6; % relative tolerance of the integral
%            
%     % step #2: create the K function to calculate the value of search
%         function K = Kfn(p)
%             K = NaN(size(p)); % this is going to be the value of search
%             [p_sort,i_sort] = sort(p);
%             N = max(size(p));
%             temp = integral(F,p(i_sort(N)),max(p_dest),'AbsTol',abstol,'RelTol',reltol);
%             K(i_sort(N)) = max(p_dest) - p(i_sort(N)) - temp;
%             for k=1:N-1
%                 l = N-k;
%                 temp = temp + integral(F,p(i_sort(l)),p(i_sort(l+1)),'AbsTol',abstol,'RelTol',reltol);
%                 K(i_sort(l)) = max(max(p_dest) - p(i_sort(l)),0) - temp;
%             end
%         end
%   
%     % step #3: integrate over the K function to get the integrals
%         integ1 = zeros(size(p_dest)); % this is going to be the value of the integral
%         [p_dest_sort,i_dest_sort] = sort(p_dest);
%         m = min(find(p_dest_sort>=p_orig));
%         M = max(size(p_dest));
%         K_int = @(x) Kfn(x).^(theta-2); % this is what we integrate
%         integ1(i_dest_sort(m)) = integral(K_int,p_orig,p_dest(i_dest_sort(m)),'AbsTol',abstol,'RelTol',reltol);
%         for h=m+1:M
%             integ1(i_dest_sort(h)) = integ1(i_dest_sort(h-1)) + integral(K_int,p_dest(i_dest_sort(h-1)),p_dest(i_dest_sort(h)),'AbsTol',abstol,'RelTol',reltol); % this way, we just integrate over the whole area once;
%         end
%     toc
%     
    % Riemann integration

        % gathering only the destination prices that are at least as great
        % as the origin prices
            [p_dest_sort,i_dest_sort] = sort(p_dest);
            M = max(size(p_dest));
            
        % using the trapezoidal numerical integration
            gridnum = 1000; % number of points to calculate integration
            gridsize = (p_dest_sort(M)-p_orig)/gridnum; % length of each grid point
            X = p_orig:gridsize:p_dest_sort(M);
            K = (p_dest_sort(M) - X) - (sum(F(X))-cumsum(F(X)))*gridsize; % value of search evaluated at each point in X
            K = max(K,0); % corrects a small rounding error that can give slightly negative values
            integ = nansum(((X'*ones(1,max(size(p_dest))))<(ones(max(size(X)),1)*p_dest')).*((K.^(theta-2))'*ones(1,max(size(p_dest)))),1)'*gridsize; % here's the approximate integral
end
            

