* This do-file prepares the data for structural estimation in Matlab, then loads the results
* written by Treb on Aug 22, 2013

clear
global date = "082213"

if c(username)=="dwi902" {
	global dropbox = "C:\Users\dwi902\Dropbox"
}

global dir = "$dropbox\Research\Trade\Information\Empirics\Structural Estimation - Monthly"
global dir_data = "$dropbox\Research\Data\Philippines\Agricultural Trade"
global dir_rain = "$dropbox\Research\Data\Philippines\Rainfall"
global dir_dem = "$dropbox\Research\Data\Philippines\2000 Demographic Census"
global dir_yield = "$dropbox\Research\Data\Philippines\Provincial Data"
global dir_phone = "$dropbox\Research\Data\Philippines\Cell phones\Towers"
cd "$dir"
cap log close
log using structest_monthly_$date.log, replace

clear
use "$dir_data\agtrade_monthly.dta"

** First, estimating the taus (and the sigma) using an IV probit (which is easier to do in Stata)
	
	* getting rainfall for IV of price ratio
		* loading rainfall data
			preserve
				clear
				use "$dir_rain\province_rain_030911.dta"
					* Converting into monthly measures
					gen month = month(date)
					gen year = year(date)
					bysort province_id year month: egen rainfall_mean = mean(rainfall_predict)
					bysort province_id year month: egen rainfall_sd = sd(rainfall_predict)
					bysort province_id year month: keep if _n==1
					lab var rainfall_mean "Mean daily rainfall over the month"
					lab var rainfall_sd "Std.dev. of daily rainfall over the month"
					drop rainfall_predict date
					
					sort province_id year month
					tempfile temp_rain
					save `temp_rain', replace			
			restore
			
		* merging
			ren province_orig_id province_id
			sort province_id year month
			merge province_id year month using `temp_rain'
			tab _merge
			ren province_id province_orig_id
			ren rainfall_mean rainfall_mean_orig
			ren rainfall_sd rainfall_sd_orig
			keep if _merge==3
			drop _merge
			
			ren province_dest_id province_id
			sort province_id year month
			merge province_id year month using `temp_rain'
			tab _merge
			ren province_id province_dest_id
			ren rainfall_mean rainfall_mean_dest
			ren rainfall_sd rainfall_sd_dest
			keep if _merge==3
			drop _merge		
			
			gen rainfall_mean_orig2 = rainfall_mean_orig^2
			gen rainfall_mean_dest2 = rainfall_mean_dest^2

	* estimating fixed effects in stata using probit transformation
		
			gen export = quantity>0
			gen ln_priceratio = ln(price_dest / price_orig)
			keep if fraction>0 /* only keeping months where production occurs */

		* identifying switchers
			bysort province_orig_id province_dest_id agprod_name: egen temp_max_export = max(export)
			bysort province_orig_id province_dest_id agprod_name: egen temp_min_export = min(export)
			keep if temp_max_export==1 & temp_min_export==0 /* only ones where we sometimes observe trade and other times do not */
			
		* collapsing down to year observations
			bysort province_orig_id province_dest_id agprod_name year: egen temp_max_priceratio = max(ln_priceratio)
			keep if temp_max_priceratio == ln_priceratio /* keeping the month with the greatest price ratio */
			bysort province_orig_id province_dest_id agprod_name year: keep if _n==1 /* in case of ties, just keep one */
			
			
		* here is the regression
			egen temp_id = group(province_orig_id province_dest_id agprod_name)

			xi: ivprobit export i.temp_id (ln_priceratio = rainfall_*), first
			local sigma = 1/_b[ln_priceratio] /* this is the estimated standard deviation */
			disp "Estimated standard deviation: " `sigma'
			* getting the estimated taus
				cap drop tau_est_incomplete
				gen tau_est_incomplete = .
				replace tau_est_incomplete = exp(-(_b[_cons]) / _b[ln_priceratio]) if temp_id==1 /* excluded fixed effect */
				qui sum temp_id
				local id_max = r(max)
				forvalues i=1/`id_max' {
					qui cap replace tau_est_incomplete = exp(-(_b[_cons] + _b[_Itemp_id_`i']) / _b[ln_priceratio]) if temp_id==`i'
				}
			
		* saving
			gen sigma = `sigma'
			lab var sigma "Estimated std.dev. of transportation costs"
			keep province_orig_id province_dest_id agprod_name tau_est_incomplete sigma
			sort province_orig_id province_dest_id agprod_name
			tempfile temp_tau
			save `temp_tau', replace
			
		* merging back on
			clear
			use "$dir_data\agtrade_monthly.dta"
			sort province_orig_id province_dest_id agprod_name
			merge province_orig_id province_dest_id agprod_name using `temp_tau'
			tab _merge
			drop _merge
			cap drop temp*
			gen temp_export = quantity>0
			drop if fraction == 0 /* only export in months where you've produced */
			bysort province_orig_id province_dest_id agprod_name: egen temp_max = max(temp_export)
			bysort province_orig_id province_dest_id agprod_name: egen temp_min = min(temp_export)
			assert tau_est_incomplete==. if temp_min==1 | temp_max==0
			replace tau_est_incomplete = -99 if tau_est_incomplete ==. & temp_min==1 /* always export */
			replace tau_est_incomplete = 99 if tau_est_incomplete ==. & temp_max==0 /* never export */
			cap drop temp*
			bysort province_orig_id province_dest_id agprod_name: assert tau_est_incomplete==tau_est_incomplete[1]
			
** Exporting data to Matlab

	* Trade flows (annual) and prices (monthly)

		* putting prices in 2000 PHP
			foreach var of var price* {
				replace `var' = `var'/(0.768) if year==1995
				replace `var' = `var'/(0.843) if year==1996
				replace `var' = `var'/(0.871) if year==1997
				replace `var' = `var'/(0.943) if year==1998
				replace `var' = `var'/(0.985) if year==1999
				replace `var' = `var'/(1) if year==2000
				replace `var' = `var'/(1.047) if year==2001
				replace `var' = `var'/(1.069) if year==2002
				replace `var' = `var'/(1.093) if year==2003
				replace `var' = `var'/(1.116) if year==2004
				replace `var' = `var'/(1.239) if year==2005
				replace `var' = `var'/(1.307) if year==2006
				replace `var' = `var'/(1.350) if year==2007
				replace `var' = `var'/(1.533) if year==2008
				replace `var' = `var'/(1.6423) if year==2009
			}
			
		preserve
		bysort province_orig_id province_dest_id agprod_name year: assert quantity == quantity[1]
		bysort province_orig_id province_dest_id agprod_name year month: assert price_dest == price_dest[1]
		bysort province_orig_id agprod_name year month: assert price_orig == price_orig[1]
		bysort province_orig_id province_dest_id agprod_name year month: keep if _n==1
		bysort province_orig_id province_dest_id agprod_name: assert tau_est_incomplete==tau_est_incomplete[1]
		keep province_orig_id province_dest_id agprod_name year month quantity price_orig price_dest tau_est_incomplete
		egen temp_id = group(province_orig_id agprod_name year month)
		
		reshape wide price_dest quantity tau_est_incomplete, i(temp_id) j(province_dest_id)
		foreach var of var price_dest* quantity* tau_est_incomplete* {
			qui replace `var' = 999 if `var'==. /* replacing missing variables so that matlab can read them */
		}
		tempfile temp_trade
		save `temp_trade', replace
		restore

	* Production (monthly) 
		preserve
		replace production_orig = production_orig / 1.53 if agprod_name=="Rice" /* this is the BAS estimate of the typical milling recover (65% of dry palay) */
		bysort province_orig_id agprod_name year: assert production_orig==production_orig[1]
		bysort province_orig_id agprod_name: assert fsub_orig==fsub_orig[1]
		bysort province_orig_id agprod_name year month: keep if _n==1
		bysort province_orig_id agprod_name year: egen temp = sum(fraction) /* what fraction of production occurs in months where there exist export markets (i.e. we observe prices elsewhere) */

		gen prod_fortrade = fraction*production_orig/temp /* amount produced in each month, forcing all trade to occur when prices are observed */
		keep province_orig_id agprod_name year month prod_fortrade
		sort province_orig_id agprod_name year month
		tempfile temp_prod
		save `temp_prod', replace
		restore

	* Land distribution (crop-province) specific
		preserve
		bysort province_orig_id agprod_name: assert theta_orig==theta_orig[1]
		bysort province_orig_id agprod_name: keep if _n==1
		keep province_orig_id agprod_name theta_orig
		tempfile temp_theta
		save `temp_theta', replace
		restore
		
	* merging
		clear
		use `temp_trade'
		sort province_orig_id agprod_name year month
		merge province_orig_id agprod_name year month using `temp_prod'
		tab _merge
		drop _merge
		
		sort province_orig_id agprod_name 
		merge province_orig_id agprod_name using `temp_theta'
		tab _merge
		drop _merge
		
	* exporting to matlab
		keep if prod_fortrade<. & theta_orig<.
		egen agprod_id = group(agprod_name)
		gen year_id = year-1994
		egen province_orig_id_matlab = group(province_orig_id)
		sort province_orig_id_matlab agprod_id year_id month
		
		outsheet province_orig_id_matlab agprod_id year_id month using "id_$date.dat", non replace
		outsheet price_dest* using "dest_prices_$date.dat", replace non
		outsheet price_orig using "orig_prices_$date.dat", replace non
		outsheet quantity* using "tradeflows_$date.dat", replace non
		outsheet prod_fortrade using "production_$date.dat", replace non
		outsheet theta_orig using "theta_$date.dat", replace non
		outsheet tau_est_incomplete* using "tauest_$date.dat", replace non
		
		* for the estimated standard deviation of the taus
		preserve
			clear
			set obs 1
			gen sigma = `sigma'
			outsheet sigma using "sigmaest_$date.dat", replace non
		restore		
		
	* saving
		save structest_tomatlab_$date.dta, replace
		
*** Importing estimates from Matlab

	clear

	* Fixed costs of search
		preserve
			clear
			insheet using "fest_082213.est"
			gen province_orig_id_matlab = _n
			drop v12
			forvalues c=1/11 {
				ren v`c' f_est`c'
			}
			reshape long f_est, i(province_orig_id_matlab) j(agprod_id)
			destring f_est, force replace	
			
			sort province_orig_id_matlab agprod_id
			tempfile temp_f_est
			save `temp_f_est', replace
		restore
		
	* Search probabilities
		forvalues c=1/11 {
			preserve
				clear
				insheet using "sest_082213_C`c'.est"
				gen province_orig_id_matlab = _n
				gen agprod_id = `c'
				drop v51
				forvalues d=1/50 {
					ren v`d' s_est`d'
				}
				reshape long s_est, i(province_orig_id_matlab) j(province_dest_id_matlab) 
				sort province_orig_id_matlab province_dest_id_matlab agprod_id
				tempfile temp_s_est_`c'
				save `temp_s_est_`c'', replace
			restore
		}
		
		preserve
			clear
			use `temp_s_est_1'
			forvalues c=2/11 {
				append using `temp_s_est_`c''
			}
			sort province_orig_id_matlab province_dest_id_matlab agprod_id
			tempfile temp_s_est
			save `temp_s_est', replace
		restore
	
	* Complete information tau estimates
		forvalues c=1/11 {
			preserve
				disp `c'
				clear
				insheet using "tauest_complete_082213_C`c'.est", non
				gen province_orig_id_matlab = _n
				gen agprod_id = `c'
				drop v51
				forvalues d=1/50 {
					destring v`d', force replace
					ren v`d' tau_est_complete`d'
				}
				reshape long tau_est_complete, i(province_orig_id_matlab) j(province_dest_id_matlab) 
				sort province_orig_id_matlab province_dest_id_matlab agprod_id
				tempfile temp_tau_est_`c'
				save `temp_tau_est_`c'', replace
			restore
		}
		
		preserve
			clear
			use `temp_tau_est_1'
			forvalues c=2/11 {
				append using `temp_tau_est_`c''
			}
			sort province_orig_id_matlab province_dest_id_matlab agprod_id
			tempfile temp_tau_est
			save `temp_tau_est', replace
		restore
		
	* Getting the original stata dataset ready
		clear
		use structest_tomatlab_$date.dta
		reshape long price_dest quantity tau_est_incomplete, i(temp_id) j(province_dest_id)
		egen province_dest_id_matlab = group(province_dest_id)
		
	* Merging onto original stata dataset
		
		* fixed costs of search
			sort province_orig_id_matlab agprod_id
			merge province_orig_id_matlab agprod_id using `temp_f_est'
			tab _merge
			drop if _merge==2
			drop _merge
			
		* search probabilities
			sort province_orig_id_matlab province_dest_id_matlab agprod_id
			merge province_orig_id_matlab province_dest_id_matlab agprod_id using `temp_s_est'
			tab _merge
			drop if _merge==2
			drop _merge
			
		* complete information estimates of tau
			sort province_orig_id_matlab province_dest_id_matlab agprod_id
			merge province_orig_id_matlab province_dest_id_matlab agprod_id using `temp_tau_est'
			tab _merge
			drop if _merge==2
			drop _merge			
			
	* need to convert fixed costs by determining how many kilograms are produced in each hectare
		preserve
		use "$dir_yield\yields_all.dta", clear
		gen agprod_name = crop
			replace agprod_name = "Rice" if crop=="Palay"
			replace agprod_name = "Sweet Potato" if crop=="Camote"
		replace yield = yield * 1000 /* now in kg / ha */
		keep agprod_name province_id year yield
		sort agprod_name province_id year
		tempfile temp_yield 
		save `temp_yield', replace
		restore
	
		ren province_orig_id province_id
		sort agprod_name province_id year
		merge agprod_name province_id year using `temp_yield'
		tab _merge if f_est<. /* great */
		drop if _merge==2
		drop _merge
		ren province_id province_orig_id

		cap drop f_est_norm
		gen f_est_norm = round(f_est*yield,1)
		lab var f_est_norm "Estimated fixed cost of search (2000PHP)"
			
	* Cleaning and saving
		destring s_est, replace force
		drop temp_id province_orig_id_matlab province_dest_id_matlab
		lab var s_est "Estimated search probability (ijc)"
		lab var f_est "Estimated fixed cost of search (ic)"
		lab var tau_est_complete "Estimated complete information transportation cost (ijc)"
		bysort province_orig_id province_dest_id agprod_name: assert s_est==s_est[1]
		bysort province_orig_id province_dest_id agprod_name: assert tau_est_complete==tau_est_complete[1]
		bysort province_orig_id agprod_name: assert f_est == f_est[1]
		
		* cleaning up the taus
			replace tau_est_incomplete=. if tau_est_incomplete==999 /* converting back to missing */
			bysort province_orig_id province_dest_id agprod_name: egen temp = mean(tau_est_incomplete) /* to get rid of missing */
			bysort province_orig_id province_dest_id agprod_name: egen tempsd = sd(tau_est_incomplete)
			sum tempsd
			assert r(mean)==0 /* so other than some missing observations due to missing prices, they are all the same */
			drop tau_est_incomplete
			ren temp tau_est_incomplete
			lab var tau_est_incomplete "Estimated transportation cost (ijc)"
			drop temp*
		
		bysort province_orig_id province_dest_id agprod_name: keep if _n==1
		keep province_orig_id province_dest_id agprod_name tau_est* f_est* s_est 
		order province_orig_id province_dest_id agprod_name tau_est* f_est s_est
		sort province_orig_id province_dest_id agprod_name
		lab dat "Structural estimates (using monthly price data)"
		save structest_monthly_$date.dta, replace
			
*** Tables and Figures for the paper

	clear
	use structest_monthly_$date.dta
	

	** Summary of structural estimates
		* transportation cost
			gen temp_tau = tau_est_incomplete
			replace temp_tau = . if abs(temp_tau)==99 /* those that are unidentified */
			replace temp_tau = 1 if temp_tau<1 /* those with estimates below 1 are set at theoretical minimum */
			sum temp_tau, detail
			
			* coefficient of variation across commodities
				cap drop temp*
				gen temp_tau = tau_est_incomplete if abs(tau_est_incomplete)<99
				bysort province_orig_id province_dest_id: egen temp_mean = mean(temp_tau)
				bysort province_orig_id province_dest_id: egen temp_sd = sd(temp_tau)
				gen temp_coeffvar = temp_sd / temp_mean
				bysort province_orig_id province_dest_id: gen temp_n = _n==1
				sum temp_coeffvar if temp_n==1
				cap drop temp*
				
		* search probabilities
			sum s_est, detail
				
			* coefficient of variation across commodities
				cap drop temp*
				bysort province_orig_id province_dest_id: egen temp_mean = mean(s_est)
				bysort province_orig_id province_dest_id: egen temp_sd = sd(s_est)
				gen temp_coeffvar = temp_sd / temp_mean
				bysort province_orig_id province_dest_id: gen temp_n = _n==1
				sum temp_coeffvar if temp_n==1
				cap drop temp*
		
		* fixed cost of search
			cap drop temp*
			bysort province_orig_id agprod_name: gen temp_n=_n==1
			sum f_est_norm if temp_n==1, detail
			
				* coefficient of variation across commodities
					preserve
					keep if temp_n==1
					bysort province_orig_id: egen temp_mean = mean(f_est_norm)
					bysort province_orig_id: egen temp_sd = sd(f_est_norm)
					gen temp_coeffvar = temp_sd / temp_mean
					bysort  province_orig_id: gen temp2 = _n==1
					sum temp_coeffvar if temp2 ==1
					restore
					cap drop temp*
					
			
	* Distribution of estimated transportation costs
	
		preserve
			bysort province_orig_id province_dest_id agprod_name: keep if _n==1
			keep if abs(tau_est_incomplete) < 99
			replace tau_est_incomplete = 1 if tau_est_incomplete<1 /* theoretical minimum */
			replace tau_est_complete = 1 if tau_est_complete<1 /* theoretical minimum */
			
			* in advalorem terms
			replace tau_est_complete = (tau_est_complete-1)
			replace tau_est_incomplete = (tau_est_incomplete-1)
			cumul tau_est_complete, gen(tau_est_complete_cdf)
			cumul tau_est_incomplete, gen(tau_est_incomplete_cdf)
			sum tau_est_complete 
			local mean_comp = r(mean)
			sum tau_est_incomplete
			local mean_incomp = r(mean)
			graph twoway (line tau_est_incomplete_cdf tau_est_incomplete if tau_est_incomplete>=0 & tau_est_incomplete<=2, sort lw(thick)) ///
				(line tau_est_complete_cdf tau_est_complete if tau_est_complete<=2 & tau_est_complete>=0, sort lw(thick) lp(dash)), ///
				xline(`mean_comp', lc(maroon) lp(dash)) xline(`mean_incomp', lc(navy)) ///
				ytitle("Cumulative Distribution") xtitle("Estimated Transportation Cost (ad valorem equivalent)") ///
				legend(lab(1 "Incomplete Information") lab(2 "Complete Information") col(1)) xlabel(0(0.2)2) ///
				saving(cdfcosts_$date, replace) graphregion(fcolor(gs16))
			graph export cdfcosts_$date.eps, replace
		restore
	
	* Estimated transportation costs and shipping distance
	
		* getting freight costs & distance
			preserve
			clear
			use "$dir_data\agtrade_monthly.dta"
			keep province_orig_id province_dest_id agprod_name year tao distance
			gen tao_nozero = tao
			replace tao_nozero = . if tao==0
			bysort province_orig_id province_dest_id agprod_name: egen tao_freight = mean(tao_nozero)
			bysort province_orig_id province_dest_id agprod_name: keep if _n==1
			sort province_orig_id province_dest_id agprod_name
			tempfile temp_freight
			save `temp_freight', replace
			restore
			
		* merging on freightcosts
			sort province_orig_id province_dest_id agprod_name
			merge province_orig_id province_dest_id agprod_name using `temp_freight'
			tab _merge
			drop if _merge==2
			drop _merge

		preserve		
			keep if abs(tau_est_incomplete) < 99
			replace tau_est_incomplete = 1 if tau_est_incomplete<1 /* theoretical minimum */
			replace tau_est_complete = 1 if tau_est_complete<1 /* theoretical minimum */
			
			gen temp_freight = (tao_freight-1)
			gen temp_complete = (tau_est_complete-1)
			gen temp_incomplete = (tau_est_incomplete-1)
			
			count
			count if temp_freight<.
			local scale = 85 /* converts pixel distance to km distance, done by comparing several of the best straightline points to calculated distance */
			local bw = 150
			gen temp_distance = distance*`scale' /* now in km */
			
			* fraction of price dispersion owing ot information frictions and distance
			gen temp_diff = temp_complete - temp_incomplete
			reg temp_diff distance
			twoway (lpolyci temp_diff temp_distance, bw(`bw') clp(solid) clw(thick) clc(navy) aco(navy) alw(thin) fi(10)), ///
				xtitle("Shipping distance (km)") ytitle("Difference between complete information" "and incomplete information estimates") ///
				legend(off) saving(info_distance_$date, replace) graphregion(fcolor(gs16))
			
			
			* transportation costs and distance
			twoway (lpolyci temp_complete temp_distance, bw(`bw') clp(dash) clw(thick) clc(maroon) aco(maroon) alw(thin) fi(10)) ///
				(lpolyci temp_incomplete temp_distance, bw(`bw') clp(solid) clw(thick) clc(navy) aco(navy) alw(thin) fi(10)) ///
				(lpolyci temp_freight temp_distance, bw(`bw') clp(dash_dot) clw(thick) clc(black) aco(black) alw(thin) fi(10)), ///
				xtitle("Shipping distance (km)") ytitle("Transportation cost (ad valorem equivalent)") ///
				legend(order(2 "Complete information" 4 "Incomplete information" 6 "Observed freight costs") col(1)) ///
				graphregion(fcolor(gs16))	saving(costs_distance_$date, replace)
				
				
			graph combine costs_distance_$date.gph info_distance_$date.gph, ///
				graphregion(fcolor(gs16)) saving(distance_combine_$date.gph, replace)
			
			graph export distance_combine_$date.eps, replace
		restore
	
	* Estimated transportation costs by commodity
		preserve
			* renaming mongo
			replace agprod_name = "Mung Bean" if agprod_name=="Mongo"
			drop if agprod_name == "Abaca" | agprod_name == "Cassava" | agprod_name == "Coffee"
			
			* next, getting rid of the unidentified observations
			drop if abs(tau_est_incomplete)==99
			replace tau_est_complete = 1 if tau_est_complete<1
			replace tau_est_incomplete = 1 if tau_est_incomplete<1
			drop if tao_freight==.
			
			* creating a ratio of estimated costs to observed freight costs
			gen tao_complete_ratio = (tau_est_complete - 1) / (tao_freight - 1)
			gen tao_incomplete_ratio = (tau_est_incomplete - 1) / (tao_freight - 1)
			sum tao_complete_ratio, detail
			qreg tao_complete_ratio
			sum tao_incomplete_ratio, detail
			
			* also getting rid of tiny observations
			bysort agprod_name: gen temp = _N
			tabstat temp, by(agprod_name)
			drop if temp<=5
			tab agprod_name
			drop temp
			
			* getting the median and standard error for all crops
					foreach var of var tao_complete_ratio tao_incomplete_ratio {
						gen `var'_med = .
						gen `var'_hi = .
						gen `var'_lo = .
					}
				
				* getting standard error of median for each category
					levelsof agprod_name, local(ag)
					foreach a of local ag {
						disp "`a'"
						foreach var of var tao_complete_ratio tao_incomplete_ratio {
							qreg `var' if agprod_name=="`a'"
								matrix define temp_b = e(b)
								matrix define temp_V = e(ci_percentile)
								replace `var'_med = _b[_cons] if agprod_name=="`a'"
								replace `var'_hi = _b[_cons] + _se[_cons] if agprod_name=="`a'"
								replace `var'_lo = _b[_cons] - _se[_cons] if agprod_name=="`a'"
						}
					}
					
									
				* now making a "Total" column
					local N = _N+1
					set obs `N'
					replace agprod_name="Total" if _n==_N
					foreach var of var tao_complete_ratio tao_incomplete_ratio {
						qreg `var'
						replace `var'_med = _b[_cons] if agprod_name=="Total"
						replace `var'_hi = _b[_cons] + _se[_cons] if agprod_name=="Total"
						replace `var'_lo = _b[_cons] - _se[_cons] if agprod_name=="Total"
					}
					
					bysort agprod_name: gen numobs = _N
					local N = _N
					replace numobs = numobs / `N' if agprod_name~="Total"
					bysort agprod_name: keep if _n==1
					qui sum numobs, detail
					local median = r(p50)
					replace numobs = `median' if agprod_name=="Total"
			
			* Making a comparison picture
			cap drop agprod_id_temp*
			egen agprod_id_temp = group(agprod_name)
			gen agprod_id_temp1 = agprod_id_temp-0.2
			gen agprod_id_temp2 = agprod_id_temp+0.2
			gen agprod_id_temp3 = agprod_id_temp-0.5
			cap drop temp*
			local N = _N+1
			set obs `N'
			replace agprod_id_temp3 = agprod_id_temp3[`N'-1]+1 if _n==`N'
			gen range_hi = 5
			gen range_lo = 2
			
			tabstat tao_incomplete_ratio_hi tao_incomplete_ratio_med tao_incomplete_ratio_lo ///
				tao_complete_ratio_hi tao_complete_ratio_med tao_complete_ratio_lo, by(agprod_name)
			
			* graph twoway  (rbar range_lo range_hi agprod_id_temp1, barwidth(1) fc(eltblue) lc(eltblue)) ///
				* (rcap tao_incomplete_ratio_hi tao_incomplete_ratio_lo agprod_id_temp1, lc(blue*0.75)) (scatter tao_incomplete_ratio agprod_id_temp1, mc(blue*0.75) m(D) msize(large)) ///
				* (rcap tao_complete_ratio_hi tao_complete_ratio_lo agprod_id_temp2, lc(red*.5)) (scatter tao_complete_ratio agprod_id_temp2, mc(red*.5) m(D) msize(large)), ///
				* xlabel(1 "Banana" 2 "Cabbage" 3 "Corn" 4 "Garlic" 5 "Onion" 6 "Pineapple" 7 "Rice" 8 "Sweet Potato" 9 "Tomato" 10 "Total", labgap(2) angle(45) labsize(small) noticks) ///
				* legend(order(3 "Incomplete Information" 5 "Complete Information" 1 "Realistic Transportation Costs")) ytitle("Estimated Transportation Cost / Observed Freight Cost") ///
				* graphregion(fcolor(gs16))
				
			graph twoway  (rbar range_lo range_hi agprod_id_temp1, barwidth(1.05) fc(eltblue) lc(eltblue*0.8)) ///
				(rcap tao_incomplete_ratio_hi tao_incomplete_ratio_lo agprod_id_temp1, lc(blue*0.75)) (scatter tao_incomplete_ratio_med agprod_id_temp1 [pweight = numobs] , mc(blue*0.75) m(D) msize(small)) ///
				(rcap tao_complete_ratio_hi tao_complete_ratio_lo agprod_id_temp2, lc(red*.5)) (scatter tao_complete_ratio_med agprod_id_temp2 [pweight = numobs], mc(red*.5) m(D) msize(small)), ///
				xlabel(1 "Banana" 2 "Cabbage" 3 "Corn" 4 "Rice" 5 "Sweet Potato" 6 "Tomato" 7 "Total", labgap(2) angle(45) labsize(small) noticks) ///
				legend(order(3 "Incomplete Information" 5 "Complete Information" 1 "Realistic Transportation Costs")) ytitle("Ratio of Estimated Transportation Cost" "to Observed Freight Cost") ///
				graphregion(fcolor(gs16)) ysc(r(0 50))
				
			graph export tao_comparison_$date.eps, replace

		restore

	* Explaining search probabilities (XXX keep? XXX)
		clear
		use structest_monthly_$date.dta
		
		* merging on cell phone data 
			preserve
				clear
				use "$dir_phone\cell_access_060311.dta"
				gen temp = towers>0
				bysort province_id year: egen phone = max(temp)
				bysort province_id year: keep if _n==1
				keep province_id year phone
				sort province_id year
				tempfile temp_phone
				save `temp_phone', replace
			restore
		
			* merging
				expand 15
				bysort province_orig_id province_dest_id agprod_name: gen year = 1994 + _n
				ren province_orig_id province_id
				sort province_id year
				merge province_id year using `temp_phone'
				tab _merge
				drop if _merge==2
				drop _merge
				ren province_id province_orig_id
				ren phone phone_orig
				
				ren province_dest_id province_id
				sort province_id year
				merge province_id year using `temp_phone'
				tab _merge
				drop if _merge==2
				drop _merge
				ren province_id province_dest_id
				ren phone phone_dest
				
			* what fraction of the sample did each pair both have cell phones?
				gen phone_both = phone_orig * phone_dest
		
		* Loading on social variables
			preserve
			clear
			use "$dir_dem\c2k2phil.dta"
				
				* creating shares
					egen temp_eth = rowtotal(eth*)
					egen temp_rel = rowtotal(rel*)
					foreach var of var eth* {
						replace `var' = `var' / temp_eth
					}
					foreach var of var rel* {
						replace `var' = `var' / temp_rel
					}
					drop temp*
					
				* crossing
					tempfile temp
					save `temp', replace
					
					foreach var of var region province eth* rel* {
						ren `var' `var'_dest
					}
					tempfile temp_dest
					save `temp_dest', replace

					clear
					use `temp'
					foreach var of var region province eth* rel* {
						ren `var' `var'_orig
					}
					
					cross using `temp_dest'
					order province_orig province_dest
					
				* Probability of two randomly drawn individuals having same ethnicity or religion
					cap drop ethnicity
					gen ethnicity=0
					lab var ethnicity "Probability two individuals will have same ethnicity"
					forvalues k = 1/143 {
						replace ethnicity=ethnicity + eth`k'_orig*eth`k'_dest
					}
					
					cap drop religion
					gen religion=0
					lab var religion "Probability two individuals will have same religion"
					forvalues k = 1/84 {
						replace religion=religion + rel`k'_orig*rel`k'_dest
					}		
				
				* cleaning and saving
					keep province_orig province_dest ethnicity religion
					ren province_orig province_orig_id
					ren province_dest province_dest_id
					sort province_orig_id province_dest_id
					tempfile temp_dem
					save `temp_dem', replace
			restore
			
			* merging
				sort province_orig_id province_dest_id
				merge province_orig_id province_dest_id using `temp_dem'
				tab _merge
				keep if _merge==3
				drop _merge
				
			* getting freight costs & distance
				preserve
				clear
				use "$dir_data\agtrade_monthly.dta"
				keep province_orig_id province_dest_id agprod_name year tao distance value
				/* converting back to PHP instead of ad valorem costs */
					gen freight = (tao-1)*value
					replace freight = . if tao==0 /* 0 indicates missing */
					gen frac_freight = freight / value
				keep province_orig_id province_dest_id agprod_name year frac_freight distance
				bysort province_orig_id province_dest_id agprod_name year: assert frac_freight == frac_freight[1]
				bysort province_orig_id province_dest_id agprod_name year: keep if _n==1
				sort province_orig_id province_dest_id agprod_name year
				tempfile temp_freight
				save `temp_freight', replace
				restore
				
			* merging on freightcosts
				sort province_orig_id province_dest_id agprod_name year
				merge province_orig_id province_dest_id agprod_name year using `temp_freight'
				tab _merge
				drop if _merge==2
				drop _merge
			
		* Regressing tau and s_est on these variables
		
			* getting logs
				cap drop ln_*
				gen ln_s = ln(s_est)
				gen tau = tau_est_incomplete
				replace tau = 1 if tau_est_incomplete<1
				replace tau = . if abs(tau_est_incomplete)==99
				gen ln_tau = ln(tau)
				foreach var of var distance frac_freight ethnicity religion {
					gen ln_`var' = ln(`var')
				}
				
			* Fixed effects
				cap drop FE*
				egen FEorigprod = group(province_orig_id agprod_name)
				egen FEdestprod = group(province_dest_id agprod_name)
				egen FEorigdestprod = group(province_orig_id province_dest_id agprod_name)
				
			* Regressions
			
				* Transportation costs
					xi: areg ln_tau ln_distance i.FEorigprod, a(FEdestprod) cluster(FEorigdestprod)
						estimates store a1
						estadd local FEic "Yes"
						estadd local FEjc "Yes"
						
					xi: areg ln_tau ln_distance ln_ethnicity ln_religion phone_both i.FEorigprod, a(FEdestprod) cluster(FEorigdestprod)
						estimates store a2
						estadd local FEic "Yes"
						estadd local FEjc "Yes"
					
				* Search probabilities
					xi: areg ln_s ln_distance i.FEorigprod, a(FEdestprod) cluster(FEorigdestprod)		
						estimates store a3
						estadd local FEic "Yes"
						estadd local FEjc "Yes"
						
					xi: areg ln_s ln_distance ln_ethnicity ln_religion phone_both i.FEorigprod, a(FEdestprod) cluster(FEorigdestprod)
						estimates store a4
						estadd local FEic "Yes"
						estadd local FEjc "Yes"

				* Observed freight costs
					xi: areg ln_frac_freight ln_distance i.FEorigprod, a(FEdestprod) cluster(FEorigdestprod)
						estimates store a5
						estadd local FEic "Yes"
						estadd local FEjc "Yes"
						
					xi: areg ln_frac_freight ln_distance ln_ethnicity ln_religion phone_both i.FEorigprod, a(FEdestprod) cluster(FEorigdestprod)
						estimates store a6
						estadd local FEic "Yes"
						estadd local FEjc "Yes"
						
			* Table
				lab var ln_distance "Log shipping distance"
				lab var ln_ethnicity "Same ethnicity"
				lab var ln_religion "Same religion"
				lab var phone_both "Mobile phone access"
				estout a3 a4 a1 a2 a5 a6 using explaining_s_$date.tex, ///
					type style(tex) replace title("Explaining Trade Frictions") ///
					prehead(\begin{table}[htbp] \caption{\sc {@title}}  \centering\medskip \label{table:explaining_s} ///
					\begin{tabular}{lllllll}) ///
					posthead("\hline") prefoot("\hline") ///
					varlabels(_cons "Constant")  ///
					cells(b(star fmt(%8.3f)) se(par fmt(%8.3f))) ///
					stats(FEic FEjc r2 N N_clust, fmt(%6.3f %6.3f %6.3f %6.0f  %6.0f) ///
					labels("Origin-Commodity FE" "Destination-Commodity FE"  "R-squared" "Observations" "Clusters")) ///
					mgroups("!$\ln \hat{s}_{ijc}!$" "!$\ln(\hat{\tau}_{ijc})!$" "Log freight costs (% of value)", lhs("Dependent variable:") pattern(1 0 1 0 1 0) span prefix(\multicolumn{@span}{c}{) suffix(})) ///
					mlabels(none) starlevels(* .1 ** .05 *** .01) collabels(none) ///
					drop(temp* _cons _I* o.*, relax) ///
					label numbers ///
					postfoot(\hline \end{tabular} \begin{minipage}{\textwidth} \emph{Notes:} Ordinary least squares.  The dependent variable is indicated above the columns. ///
						Each observation is an origin-destination-commodity-year quadruplet. Standard errors are clustered at the origin-destination-commodity level to account for the fact that ///
						the estimated search probabilities and transportation costs are time invariant (each year is included separately in the regression to allow the mobile phone access variable to differ by year).  ///
						"Same ethnicity" and "same religion" are equal to the (log) probability that a randomly selected individual ///
						in the origin province has the same ethnicity or religion, respecitively, of a randomly selected individual in ///
						the destination province. Mobile phone access is an indicator variable equal to one if a civilian cell phone tower exists in both the origin and destination provinces in a given year. ///
						Standard errors clustered at origin-destination-commodity level reported in parentheses. Stars indicate statistical significance: * p<.10 ** p<.05 *** p<.01. ///
					\end{minipage} \end{table} ) substitute($ \$ !$ $ ~ .\ % \%)	
					
	
	
	
	